<?php
//namespace LiquidElementor\Elementor;

defined( 'ABSPATH' ) || die();

class LD_HF_AdminBarMenu {

    public static function init() {
        if( current_user_can('edit_posts') ) {
            add_action( 'admin_bar_menu', [ __CLASS__, 'add_toolbar_items' ], 100 );
        }
    }
    
    public static function add_toolbar_items( $admin_bar ){

        $admin_bar->add_menu( [
            'id'    => 'ld-edit-header-footer',
            'title' => 'Edit Header & Footer',
            'href'  => '#',
            'meta'  => [
                'title' => __( 'Edit Header & Footer', 'hub-elementor-addons'),            
            ],
        ]);

        $header_and_footer = array_merge(self::get_available_custom_post('liquid-header'), self::get_available_custom_post('liquid-footer'));
       
        foreach ($header_and_footer as $item ){
            if (liquid_get_custom_header_id() == $item['id'] || liquid_get_custom_footer_id() == $item['id']){
                $current = '<span class="ld-edit-header-footer-current">Current</span>';
            } else {
                $current = '';
            }

            $admin_bar->add_menu( [
                'id' => 'ld-edit-header-footer-' . $item['id'],
                'parent' => 'ld-edit-header-footer',
                'title' => sprintf( '%s - %s %s', $item['title'], $item['type'], $current),
                'href' => \Elementor\Plugin::$instance->documents->get( $item['id'] )->get_edit_url(),
                'meta' => [
                    'title' => $item['title'],
                    'target' => '_blank',
                    'class' => 'ld_edit_header_footer ' . strtolower( $item['type'] ),
                ],
            ]);
        }
       
    }

    private static function get_available_custom_post( $type ) {
		$posts = get_posts( array(
			'post_type' => $type,
			'posts_per_page' => -1,
		) );

		$options = [];
	
        $type = $type === 'liquid-header' ? 'Header' : 'Footer';

		foreach ( $posts as $post ) {
		  $options[] = [ 'id' => $post->ID, 'title' => $post->post_title, 'type' => $type ];
		}
	
		return $options;
	}

}
LD_HF_AdminBarMenu::init();