<?php 

if (!defined('ABSPATH')) {
    exit;
} // Exit if accessed directly

if (!class_exists('Liquid_Elementor_Widget_Assets')) :

    class Liquid_Elementor_Widget_Assets{

        public function __construct(){

            $this->init_hooks();

        }

        private function init_hooks(){

            add_action( 'elementor/frontend/before_enqueue_styles', [ $this, 'widget_styles' ] );
            add_action( 'elementor/frontend/widget/after_render', [ $this, 'enq_widget_assets' ], 9999 );
            add_action( 'wp_footer', function(){
                //print_r(get_option('lqd_merged_js'));
            });

            // show warn
            $theme_option = get_option('liquid_one_opt');
            // Combine CSS
            if ( $this->check_combine_css() ) {
                add_action( 'wp_footer', function(){
                    global $wp_styles;
                    ?>
                        <div style="
                        position:fixed;
                        bottom:1em;
                        right:1em;
                        padding:1em;
                        background:#ffc600;
                        color:#000;
                        font-weight:bold;
                        z-index:999;
                        ">
                        DEV: Combined CSS active!<br>
                        <div style="font-size:12px;">Included Files:
                            <ul>
                            <?php 
                            foreach ( get_option('lqd_merged_css') as $style ){
                                $url = $wp_styles->registered[$style]->src;
                                echo "<li><a target=\"_blank\" href=\"$url\">$style</a></li>";
                            }
                            ?>
                            </ul>
                            <a href="<?php echo esc_url( wp_upload_dir()['baseurl'] . '/merged-styles.css' ); ?>" target="_blank">show merged css</a>
                        </div>
                        </div>
                    <?php

   
                    $this->merge_all_separated_styles();
                }, 9999);
            }

            // Combine JS
            if ( $this->check_combine_js() ) {
                add_action( 'wp_footer', function(){
                    global $wp_scripts;
                    ?>
                        <div style="
                        position:fixed;
                        bottom:1em;
                        right:1em;
                        padding:1em;
                        background:#ffc600;
                        color:#000;
                        font-weight:bold;
                        z-index:999;
                        ">
                        DEV: Combined JS active!<br>
                        <div style="font-size:12px;">Included Files:
                            <ul>
                            <?php 
                            foreach ( get_option('lqd_merged_js') as $style ){
                                $url = $wp_scripts->registered[$style]->src;
                                echo "<li><a target=\"_blank\" href=\"$url\">$style</a></li>";
                            }
                            ?>
                            </ul>
                            <a href="<?php echo esc_url( wp_upload_dir()['baseurl'] . '/merged-scripts.js' ); ?>" target="_blank">show merged js</a>
                        </div>
                        </div>
                    <?php

   
                    $this->merge_all_separated_scripts();
                }, 9999);
            }

            if (isset($theme_option['enable_combine_css_log']) && $theme_option['enable_combine_css_log'] === 'on') {
                add_action( 'wp_footer', function(){
                    global $wp_styles;
    
                ?>
                    <div style="
                   
                    bottom:1em;
                    left:1em;
                    padding:1em;
                    background:#ffc600;
                    color:#000;
                    font-weight:bold;
                    z-index:999;
                    position:fixed;
                    ">
                    Loaded Separated CSS (on Footer):
                    <div style="font-size:10px;">
                        <ol>
                        <?php 
                        foreach ( $wp_styles->queue as $style ){
                            if ( substr($style, 0, 7) === 'lqdsep-' ){
                                echo "<li>$style</li>";
                            }
                        }
                        echo $this->check_combine_css() ? 'separated files was deq.<br>check merged.css' : '';
                        ?>
                        </ol>
                    </div>
                    </div>
                <?php
    
                });
            }

        }

        public function widget_styles() {

            $src = [
                'lqdsep-button-ajax-loadmore' =>  'button/button-ajax-loadmore.css',
                'lqdsep-btn-base' =>  'button/button-base.css',
                'lqdsep-btn-hover-reveal' =>  'button/button-hover-reveal.css',
                'lqdsep-btn-hover-swap' =>  'button/button-hover-swap.css',
                'lqdsep-btn-hover-txt-liquid-x-alt' =>  'button/button-hover-txt-liquid-x-alt.css',
                'lqdsep-btn-hover-txt-liquid-x' =>  'button/button-hover-txt-liquid-x.css',
                'lqdsep-btn-hover-txt-liquid-y-alt' =>  'button/button-hover-txt-liquid-y-alt.css',
                'lqdsep-btn-hover-txt-liquid-y' =>  'button/button-hover-txt-liquid-y.css',
                'lqdsep-btn-icon-base' =>  'button/button-icon-base.css',
                'lqdsep-btn-icon-ripple' =>  'button/button-icon-ripple.css',
                'lqdsep-btn-icon-sep' =>  'button/button-icon-sep.css',
                'lqdsep-button-icon-shape' =>  'button/button-icon-shape.css',
                'lqdsep-button-icon-size' =>  'button/button-icon-size.css',
                'lqdsep-button-shape-plain' =>  'button/button-shape-plain.css',
                'lqdsep-button-shape-solid' =>  'button/button-shape-solid.css',
                'lqdsep-button-shape-underline' =>  'button/button-shape-underline.css',
                'lqdsep-btn-size' =>  'button/button-size.css'
            ];

            // Register all seperated css files.
            foreach ( $src as $name => $path ){
                wp_register_style( 
                    $name, 
                    get_template_directory_uri() . '/assets/css/elements/' . $src[$name], 
                    [],
                    LD_ELEMENTOR_VERSION
                );
            }

            $src = [
                'lqdsep-btn-base' =>  'button/button-base.js',
                'lqdsep-btn-hover-txt-liquid-x-alt' =>  'button/button-bover-txt-liquid-x-alt.js'
            ];

            // Register all seperated js files.
            foreach ( $src as $name => $path ){
                wp_register_script( 
                    $name, 
                    get_template_directory_uri() . '/assets/js/elements/' . $src[$name], 
                    [],
                    LD_ELEMENTOR_VERSION
                );
            }
    
        }

        function enq_widget_assets( \Elementor\Element_Base $element ){

            $arr = $arr_js = array();
            $combined_css = $this->check_combine_css();
            $combined_js = $this->check_combine_js();

            //update_option('liquid_dequeue_widget_style', '');
            // enqueue css files by option
            if ( $element->get_name() === 'ld_button' ) {

                $combined_css ? $arr[] = 'lqdsep-btn-base' : wp_enqueue_style( 'lqdsep-btn-base' );
                $combined_js ? $arr_js[] = 'lqdsep-btn-base' : wp_enqueue_script( 'lqdsep-btn-base' );

                if ( $element->get_settings( 'hover_txt_effect' ) === 'btn-hover-txt-liquid-x' ){
                    $combined_css ? $arr[] = 'lqdsep-btn-hover-txt-liquid-x' : wp_enqueue_style( 'lqdsep-btn-hover-txt-liquid-x' );
                } 
                if ( $element->get_settings( 'hover_txt_effect' ) === 'btn-hover-txt-liquid-x-alt' ){
                    $combined_css ? $arr[] = 'lqdsep-btn-hover-txt-liquid-x-alt' : wp_enqueue_style( 'lqdsep-btn-hover-txt-liquid-x-alt' );
                    $combined_js ? $arr_js[] = 'lqdsep-btn-hover-txt-liquid-x-alt' : wp_enqueue_script( 'lqdsep-btn-hover-txt-liquid-x-alt' );
                } 
                if ( $element->get_settings( 'hover_txt_effect' ) === 'btn-hover-txt-liquid-y-alt' ){
                    $combined_css ? $arr[] = 'lqdsep-btn-hover-txt-liquid-y-alt' : wp_enqueue_style( 'lqdsep-btn-hover-txt-liquid-y-alt' );
                } 
                if ( $element->get_settings( 'hover_txt_effect' ) === 'btn-hover-txt-liquid-y' ){
                    $combined_css ? $arr[] = 'lqdsep-btn-hover-txt-liquid-y' : wp_enqueue_style( 'lqdsep-btn-hover-txt-liquid-y' );
                } 
                if ( $element->get_settings( 'i_hover_reveal' ) === 'btn-hover-reveal' ){
                    $combined_css ? $arr[] = 'lqdsep-btn-hover-reveal' : wp_enqueue_style( 'lqdsep-btn-hover-reveal' );
                } 
                if ( $element->get_settings( 'i_hover_reveal' ) === 'btn-hover-swp' ){
                    $combined_css ? $arr[] = 'lqdsep-btn-hover-swap' : wp_enqueue_style( 'lqdsep-btn-hover-swap' );
                }
                if ( $element->get_settings( 'i_add_icon' ) === 'true' ){
                    $combined_css ? $arr[] = 'lqdsep-btn-icon-base' : wp_enqueue_style( 'lqdsep-btn-icon-base' );
                }
                
            }

            update_option('lqd_merged_css', $arr, 'yes');
            update_option('lqd_merged_js', $arr_js, 'yes');
    
        }

        function check_combine_css(){

            $theme_option = get_option('liquid_one_opt');
            if (isset($theme_option['enable_combine_css']) && $theme_option['enable_combine_css'] === 'on') {
                return true;
            } else {
                return false;
            }

        }
        
        function check_combine_js(){

            $theme_option = get_option('liquid_one_opt');
            if (isset($theme_option['enable_combine_js']) && $theme_option['enable_combine_js'] === 'on') {
                return true;
            } else {
                return false;
            }

        }

        function merge_all_separated_styles() {

            global $wp_styles;
            
            /*
                #1. Reorder the handles based on its dependency, 
                    The result will be saved in the to_do property ($wp_scripts->to_do)
            */

            //$wp_styles->all_deps($wp_styles->queue);	

            $uploads = wp_upload_dir();
            
            $merged_file_location = $uploads['basedir'] . DIRECTORY_SEPARATOR . 'merged-styles.css';
            
            $merged_script = '';

            $styles = get_option('lqd_merged_css');

            // Loop javascript files and save to $merged_script variable
            foreach( $styles as $handle ) {
                # Clean up url

                $src = strtok($wp_styles->registered[$handle]->src, '?');
                #2. Combine CSS file.            

                // If src is url http / https
                
                if (strpos($src, 'http') !== false){
                    // Get our site url
                    $site_url = site_url();
                
                    /*
                        If we are on local server, then change url to relative path
                    */

                    if (strpos($src, $site_url) !== false)
                        $js_file_path = str_replace($site_url, '', $src);
                    else
                        $js_file_path = $src;
                    
                    /*
                        To be able to use file_get_contents function we need to remove slash
                    */

                    $js_file_path = ltrim($js_file_path, '/');
                }
                else {			
                    $js_file_path = ltrim($src, '/');
                }
                
                // Check wether file exists then merge

                if  (file_exists($js_file_path)) {
                    #3. Check for wp_localize_script

                    $localize = '' ;

                    if (@key_exists('after', $wp_styles->registered[$handle]->extra)) {
                        //$localize = $wp_styles->registered[$handle]->extra['after']['1'] . ';';
                    }

                    $merged_script .=  $localize . file_get_contents($js_file_path);
                }
            }
            
            // write the merged script into current theme directory
            file_put_contents ( $merged_file_location , $merged_script);
            
            // #4. Load the URL of merged file

            // wp_enqueue_style('merged-styles',  $uploads['baseurl'] . '/merged-styles.css');
            
            // 5. Deregister handles
            update_option('lqd_merged_css', array(), 'yes' );
            /* Not need 
            foreach( $styles as $handle ) {
                if ( substr($handle, 0, 7) === 'lqdsep-' ){
                    wp_deregister_style($handle);
                }
            }
            */
        }
        function merge_all_separated_scripts() {

            global $wp_scripts;
            
            /*
                #1. Reorder the handles based on its dependency, 
                    The result will be saved in the to_do property ($wp_scripts->to_do)
            */

            //$wp_scripts->all_deps($wp_styles->queue);	

            $uploads = wp_upload_dir();
            
            $merged_file_location = $uploads['basedir'] . DIRECTORY_SEPARATOR . 'merged-scripts.js';
            
            $merged_script = '';

            $scripts = get_option('lqd_merged_js');

            // Loop javascript files and save to $merged_script variable
            foreach( $scripts as $handle ) {
                # Clean up url

                $src = strtok($wp_scripts->registered[$handle]->src, '?');
                #2. Combine CSS file.            

                // If src is url http / https
                
                if (strpos($src, 'http') !== false){
                    // Get our site url
                    $site_url = site_url();
                
                    /*
                        If we are on local server, then change url to relative path
                    */

                    if (strpos($src, $site_url) !== false)
                        $js_file_path = str_replace($site_url, '', $src);
                    else
                        $js_file_path = $src;
                    
                    /*
                        To be able to use file_get_contents function we need to remove slash
                    */

                    $js_file_path = ltrim($js_file_path, '/');
                }
                else {			
                    $js_file_path = ltrim($src, '/');
                }
                
                // Check wether file exists then merge

                if  (file_exists($js_file_path)) {
                    #3. Check for wp_localize_script

                    $localize = '' ;

                    if (@key_exists('after', $wp_scripts->registered[$handle]->extra)) {
                        //$localize = $wp_styles->registered[$handle]->extra['after']['1'] . ';';
                    }

                    $merged_script .=  $localize . file_get_contents($js_file_path) . ';';
                }
            }
            
            // write the merged script into current theme directory
            file_put_contents ( $merged_file_location , $merged_script);
            
            // #4. Load the URL of merged file

            // wp_enqueue_style('merged-styles',  $uploads['baseurl'] . '/merged-styles.css');
            
            // 5. Deregister handles
            update_option('lqd_merged_js', array(), 'yes' );
            /* Not need 
            foreach( $styles as $handle ) {
                if ( substr($handle, 0, 7) === 'lqdsep-' ){
                    wp_deregister_style($handle);
                }
            }
            */
        }
        



    }
    new Liquid_Elementor_Widget_Assets();

endif;