<?php
namespace LiquidElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Schemes\Color;
use Elementor\Schemes\Typography;
use Elementor\Utils;
use Elementor\Control_Media;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Repeater;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Elementor heading widget.
 *
 * Elementor widget that displays an eye-catching headlines.
 *
 * @since 1.0.0
 */
class LD_Accordion extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve heading widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'ld_accordion';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve heading widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Liquid Accordion', 'hub-elementor-addons' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve heading widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-accordion lqd-element';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the heading widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'hub-core' ];
	}

	/**
	 * Get widget keywords.
	 *
	 * Retrieve the list of keywords the widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget keywords.
	 */
	public function get_keywords() {
		return [ 'accordion', 'tab', 'toggle' ];
	}

	/**
	 * Register heading widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

		// Items Section
		$this->start_controls_section(
			'items_section',
			[
				'label' => __( 'Items', 'hub-elementor-addons' ),
			]
		);

		
		$repeater = new Repeater();

		$repeater->add_control(
			'title',
			array(
				'label' => __( 'Title', 'hub-elementor-addons' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Accordion Title', 'hub-elementor-addons' ),
				'dynamic' => array(
					'active' => true,
				),
				'label_block' => true,
			)
		);
		$repeater->add_control(
			'content',
			array(
				'label' => __( 'Content', 'hub-elementor-addons' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => __( 'Accordion Content', 'hub-elementor-addons' ),
				'show_label' => false,
			)
		);

		$this->add_control(
			'items',
			array(
				'label' => __( 'Accordion Items', 'hub-elementor-addons' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'title' => __( 'Accordion #1', 'hub-elementor-addons' ),
						'content' => __( '<p>Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>', 'hub-elementor-addons' ),
					],
					[
						'title' => __( 'Accordion #2', 'hub-elementor-addons' ),
						'content' => __( '<p>Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>', 'hub-elementor-addons' ),
					],
				],
				'title_field' => '{{{ title }}}',
			)
		);
		$this->end_controls_section();

		// General Section
		$this->start_controls_section(
			'general_section',
			array(
				'label' => __( 'Accordion', 'hub-elementor-addons' ),
			)
		);

		$this->add_control(
			'active_tab',
			[
				'label' => __( 'Active tab', 'hub-elementor-addons' ),
				'description' => __( 'Enter active tab. Set this to -1 if you want all the tabs closed.', 'hub-elementor-addons' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
			]
		);

		$this->add_control(
			'size',
			[
				'label' => __( 'Title Height', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'sm',
				'options' => [
					'xs' => __( 'Shortest', 'hub-elementor-addons' ),
					'sm' => __( 'Short', 'hub-elementor-addons' ),
					'md' => __( 'Medium', 'hub-elementor-addons' ),
					'lg' => __( 'Tall', 'hub-elementor-addons' ),
				],
			]
		);

		$this->add_control(
			'borders',
			[
				'label' => __( 'Border Style', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => __( 'None', 'hub-elementor-addons' ),
					'accordion-title-bordered' => __( 'Title Bordered', 'hub-elementor-addons' ),
					'accordion-title-underlined' => __( 'Title Underlined', 'hub-elementor-addons' ),
					'accordion-body-underlined' => __( 'Content Underlined', 'hub-elementor-addons' ),
					'accordion-body-bordered' => __( 'Content Bordered', 'hub-elementor-addons' ),
				],
			]
		);

		$this->add_control(
			'border_round',
			[
				'label' => __( 'Border Round', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => __( 'None', 'hub-elementor-addons' ),
					'accordion-title-round' => __( 'Round', 'hub-elementor-addons' ),
					'accordion-title-circle' => __( 'Circle', 'hub-elementor-addons' ),
				],
				'condition' => array(
					'borders' => 'accordion-title-bordered',
				)
			]
		);

		$this->add_control(
			'body_border_round',
			[
				'label' => __( 'Border Round', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => __( 'None', 'hub-elementor-addons' ),
					'accordion-body-round' => __( 'Round', 'hub-elementor-addons' ),
				],
				'condition' => array(
					'borders' => 'accordion-body-bordered',
				)
			]
		);

		$this->add_control(
			'items_shadow',
			[
				'label' => __( 'Accordion Item Shadow', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'On', 'hub-elementor-addons' ),
				'label_off' => __( 'Off', 'hub-elementor-addons' ),
				'return_value' => 'yes',
				'default' => '',
			]
		);

		$this->add_control(
			'heading_shadow',
			[
				'label' => __( 'Heading Shadow', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'On', 'hub-elementor-addons' ),
				'label_off' => __( 'Off', 'hub-elementor-addons' ),
				'return_value' => 'yes',
				'default' => '',
			]
		);

		$this->add_control(
			'active_style',
			[
				'label' => __( 'Active Heading Shadow', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'On', 'hub-elementor-addons' ),
				'label_off' => __( 'Off', 'hub-elementor-addons' ),
				'return_value' => 'yes',
				'default' => '',
				'condition' => array(
					'items_shadow' => ''
				)
			]
		);
		
		$this->add_control(
			'bottom_margin',
			[
				'label' => __( 'Items Bottom Margin', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 200,
						'step' => 1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 0,
				],
				'selectors' => [
					'{{WRAPPER}} .accordion-item:not(:last-child)' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);

		$this->add_responsive_control(
			'content_padding',
			[
				'label' => __( 'Content Padding', 'hub-elementor-addons' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'default' => [
					'unit' => 'em',
					'top' => '1',
					'bottom' => '1',
					'isLinked' => false,
				],
				'selectors' => [
					'{{WRAPPER}} .accordion-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'separator' => 'before'
			]
		);

		$this->end_controls_section();

		// Expander Section
		$this->start_controls_section(
			'expander_section',
			[
				'label' => __( 'Expander', 'hub-elementor-addons' ),
			]
		);

		$this->add_control(
			'show_icon',
			[
				'label' => __( 'Enable Expander', 'hub-elementor-addons' ),
				'description' => __( 'If enabled will show icons in expander', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'On', 'hub-elementor-addons' ),
				'label_off' => __( 'Off', 'hub-elementor-addons' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'expander_position',
			[
				'label' => __( 'Expander position', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => __( 'Default', 'hub-elementor-addons' ),
					'accordion-expander-left' => __( 'Left', 'hub-elementor-addons' ),
				],
				'condition' => array(
					'show_icon' => 'yes',
				)
			]
		);

		$this->add_control(
			'expander_size',
			[
				'label' => __( 'Expander position', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => __( 'Normal', 'hub-elementor-addons' ),
					'accordion-expander-lg' => __( 'Large ( 22px )', 'hub-elementor-addons' ),
					'accordion-expander-xl' => __( 'xLarge ( 26px )', 'hub-elementor-addons' ),
				],
				'condition' => array(
					'show_icon' => 'yes',
				)
			]
		);
		$this->end_controls_section();

		// Icon Section
		$this->start_controls_section(
			'icon_section',
			[
				'label' => __( 'Icon', 'hub-elementor-addons' ),
				'condition' => array(
					'show_icon' => 'yes',
				)
			]
		);

		$this->add_control(
			'i_add_icon',
			[
				'label' => __( 'Normal State Icon', 'hub-elementor-addons' ),
				'description' => __( 'Normal state of the panel', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'On', 'hub-elementor-addons' ),
				'label_off' => __( 'Off', 'hub-elementor-addons' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);

		$this->add_control(
			'i_type',
			[
				'label' => __( 'Icon Library', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'fontawesome',
				'options' => [
					'fontawesome'  => __( 'Icon Library', 'hub-elementor-addons' ),
					'image' => __( 'Image', 'hub-elementor-addons' ),
				],
				'condition' => array(
					'i_add_icon' => 'true'
				)
			]
		);

		$this->add_control(
			'i_icon_fontawesome',
			[
				'label' => __( 'Icon', 'hub-elementor-addons' ),
				'type' => Controls_Manager::ICONS,
				'default' => [
					'value' => 'fa fa-chevron-down',
					'library' => 'solid',
				],
                'condition' => array(
                    'i_type' => 'fontawesome',
					'i_add_icon' => 'true'
                ),
			]
		);

		$this->add_control(
			'i_icon_image',
			[
				'label' => __( 'Image', 'hub-elementor-addons' ),
				'type' => Controls_Manager::MEDIA,
				'condition' => array(
                    'i_type' => 'image',
					'i_add_icon' => 'true'
                ),
			]
		);

		// active icon

		$this->add_control(
			'active_add_icon',
			[
				'label' => __( 'Active State Icon', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'On', 'hub-elementor-addons' ),
				'label_off' => __( 'Off', 'hub-elementor-addons' ),
				'return_value' => 'true',
				'default' => 'true',
				'separator' => 'before'
			]
		);

		$this->add_control(
			'active_type',
			[
				'label' => __( 'Icon Library', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'fontawesome',
				'options' => [
					'fontawesome'  => __( 'Icon Library', 'hub-elementor-addons' ),
					'image' => __( 'Image', 'hub-elementor-addons' ),
				],
				'condition' => array(
					'active_add_icon' => 'true'
				)
			]
		);

		$this->add_control(
			'active_icon_fontawesome',
			[
				'label' => __( 'Icon', 'hub-elementor-addons' ),
				'type' => Controls_Manager::ICONS,
				'default' => [
					'value' => 'fa fa-chevron-up',
					'library' => 'solid',
				],
                'condition' => array(
                    'active_type' => 'fontawesome',
					'active_add_icon' => 'true'
                ),
			]
		);

		$this->add_control(
			'active_icon_image',
			[
				'label' => __( 'Image', 'hub-elementor-addons' ),
				'type' => Controls_Manager::MEDIA,
				'condition' => array(
                    'active_type' => 'image',
					'active_add_icon' => 'true'
                ),
			]
		);
		$this->end_controls_section();

		// Style Tab
		$this->start_controls_section(
			'style_section',
			[
				'label' => __( 'Typography', 'hub-elementor-addons' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'heading_typography',
				'label' => __( 'Heading Typography', 'hub-elementor-addons' ),
				'selector' => '{{WRAPPER}} .accordion-title a',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'content_typography',
				'label' => __( 'Content Typography', 'hub-elementor-addons' ),
				'selector' => '{{WRAPPER}} .accordion-content',
			]
		);

		$this->end_controls_section();

		// Background cikir
		$this->start_controls_section(
			'bg_section',
			[
				'label' => __( 'Background colors', 'hub-elementor-addons' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'bg_options',
			[
				'label' => __( 'Content background', 'hub-elementor-addons' ),
				'type' => Controls_Manager::HEADING,
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'content_bg',
				'label' => __( 'Content background', 'hub-elementor-addons' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .accordion-content'
			]
		);

		$this->add_control(
			'heading_option',
			[
				'label' => __( 'Heading background', 'hub-elementor-addons' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'heading_bg_color',
				'label' => __( 'Heading background', 'hub-elementor-addons' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .accordion-title a',
			]
		);

		$this->add_control(
			'active_heading_option',
			[
				'label' => __( 'Active heading background', 'hub-elementor-addons' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'heading_active_bg_color',
				'label' => __( 'Active heading background', 'hub-elementor-addons' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .accordion-item.active .accordion-title a',
			]
		);

		$this->end_controls_section();

		// Border section
		$this->start_controls_section(
			'border_color_section',
			[
				'label' => __( 'Border colors', 'hub-elementor-addons' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'border_color',
			[
				'label' => __( 'Heading border color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .accordion-title a, {{WRAPPER}} .accordion-item' => 'border-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'active_border_color',
			[
				'label' => __( 'Active Heading border color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .accordion-item.active .accordion-title a, {{WRAPPER}} .accordion-item.active' => 'border-color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();

		// Text color section
		$this->start_controls_section(
			'text_color_section',
			[
				'label' => __( 'Text colors', 'hub-elementor-addons' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'heading_color_options',
			[
				'label' => __( 'Heading colors', 'hub-elementor-addons' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'heading_color',
			[
				'label' => __( 'Heading color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .accordion-title a' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'active_heading_color',
			[
				'label' => __( 'Active heading color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .accordion-item.active .accordion-title a' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'content_color',
			[
				'label' => __( 'Content text color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .accordion-content' => 'color: {{VALUE}}',
				],
			]
		);

		// Expander color
		$this->add_control(
			'exp_color_options',
			[
				'label' => __( 'Expander Colors', 'hub-elementor-addons' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => array(
					'show_icon' => 'yes'
				)
			]
		);

		$this->add_control(
			'exp_color',
			[
				'label' => __( 'Expander color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .accordion-expander' => 'color: {{VALUE}}',
				],
				'condition' => array(
					'show_icon' => 'yes'
				)
			]
		);

		$this->add_control(
			'active_exp_color',
			[
				'label' => __( 'Expander active color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .accordion-item.active .accordion-expander' => 'color: {{VALUE}}',
				],
				'condition' => array(
					'show_icon' => 'yes'
				)
			]
		);
		$this->end_controls_section();

	}

	/**
	 * Render heading widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		
		$settings = $this->get_settings_for_display();
		$settings['size'] = 'accordion-'.$settings['size'];

		if($settings['items_shadow'] === 'yes') $settings['items_shadow'] = 'accordion-body-shadow';
		if($settings['heading_shadow'] === 'yes') $settings['heading_shadow'] = 'accordion-heading-has-shadow';
		if($settings['active_style'] === 'yes') $settings['active_style'] = 'accordion-active-has-shadow';

		$active_has_fill = '';
		if( ! empty( $settings['bg_color'] ) || ! empty( $settings['active_bg_color'] ) ) {
			$active_has_fill = 'accordion-active-has-fill';
		}

		$wrapper_class = array(
			'accordion', 
			$settings['borders'], 
			$settings['size'], 
			$settings['border_round'], 
			$settings['body_border_round'], 
			$settings['expander_position'],
			$settings['expander_size'],
			$settings['items_shadow'],
			$settings['heading_shadow'],
			$settings['active_style'],
			(!empty($settings['content_bg'])) ? 'accordion-content-has-fill' : '',
			$active_has_fill,
		);

		$settings['active_tab'] = ! empty( $settings['active_tab'] ) ? intval( $settings['active_tab'] ) - 1 : 0;
		$parent = uniqid( 'accordion-' );

		?>

		<div class="<?php echo ld_helper()->sanitize_html_classes( $wrapper_class ); ?>" id="<?php echo esc_attr($parent) ?>" role="tablist" aria-multiselectable="true">
			<?php $id_int = substr( $this->get_id_int(), 0, 3 ); ?>
			<?php foreach (  $settings['items'] as $i => $item ) : ?>
			<?php
			$tab_count = $i + 1;
			$tab_content_setting_key = $this->get_repeater_setting_key( 'content', 'items', $i );
			$this->add_render_attribute( $tab_content_setting_key, [
				'class' => [ 'accordion-content' ],
			] );
	
			$this->add_inline_editing_attributes( $tab_content_setting_key, 'advanced' );

			$in = $i == $settings['active_tab'] ? ' in' : '';
			$active = $i == $settings['active_tab'] ? ' active' : '';
			$expanded = $i == $settings['active_tab'] ? 'true' : 'false';
			$collapsed = $i == $settings['active_tab'] ? '' : 'collapsed';
			?>
			<div class="accordion-item panel <?php echo $active; ?>">
				
				<div class="accordion-heading" role="tab" id="<?php echo 'heading-'.$id_int . $tab_count ?>">
				<h4 class="accordion-title">
					<a class="<?php echo $collapsed ?>" role="button" data-toggle="collapse" 
					data-parent="#<?php echo $parent ?>" href="#<?php echo 'collapse-'.$id_int . $tab_count ?>" 
					aria-expanded="<?php echo $expanded ?>" aria-controls="<?php echo 'collapse-'.$id_int . $tab_count; ?>">
	
						<?php echo $item['title']; ?>

						<span class="accordion-expander">
							<i class="<?php echo isset($settings['i_icon_fontawesome']['value']) ? $settings['i_icon_fontawesome']['value'] : ''; ?>"></i>
							<i class="<?php echo isset($settings['active_icon_fontawesome']['value']) ? $settings['active_icon_fontawesome']['value'] : ''; ?>"></i>
						</span>
					</a>
				</h4>
				</div>
				
				<div id="<?php echo 'collapse-'.$id_int . $tab_count ?>" class="accordion-collapse collapse <?php echo $in ?>" role="tabpanel" aria-labelledby="<?php echo 'heading-'.$id_int . $tab_count; ?>">

				<div <?php echo $this->get_render_attribute_string( $tab_content_setting_key ); ?>>
					<?php echo $item['content']; ?>
				</div>
						
				</div>
				
			</div>
			<?php endforeach; ?>
			
		</div>

		<?php

	}

	protected function _content_template() {
		?>

		<#

		const wrapper_class = [
			'accordion', 
			settings.borders, 
			'accordion-'+settings.size, 
			settings.border_round, 
			settings.body_border_round, 
			settings.expander_position,
			settings.expander_size,
			(settings.items_shadow === 'yes' ? 'accordion-body-shadow' : ''),
			(settings.heading_shadow === 'yes' ? 'accordion-heading-has-shadow' : ''),
			(settings.active_style === 'yes' ? 'accordion-active-has-shadow' : ''),
			(settings.content_bg ? 'accordion-content-has-fill' : ''),
			(settings.bg_color || settings.active_bg_color ? 'accordion-active-has-fill' : ''),
		].filter(classname => classname !== '');

		const parent = 'accordion-' + Date.now();
		view.addRenderAttribute(
			'wrapper',
			{
				'class': [ wrapper_class.join(' ') ],
				'id': parent,
				'role': 'tablist',
				'aria-multiselectable': 'true',
			}
		);

		settings.active_tab = settings.active_tab ? settings.active_tab - 1 : 0;

		#>
		<div {{{ view.getRenderAttributeString( 'wrapper' ) }}}>
		<#
			if ( settings.items ) {
				var tabindex = view.getIDInt().toString().substr( 0, 3 );

				_.each( settings.items, function( item, i ) {
					var tabCount = i + 1,
						__in = i == settings.active_tab ? ' in' : '',
						active = i == settings.active_tab ? ' active' : '',
						expanded = i == settings.active_tab ? 'true' : 'false',
						collapsed = i == settings.active_tab ? '' : 'collapsed',
						tabTitleKey = view.getRepeaterSettingKey( 'title', 'items', i ),
						tabContentKey = view.getRepeaterSettingKey( 'content', 'items', i );

					view.addRenderAttribute( tabTitleKey, {
						'class': collapsed,
						'role': 'button',
						'data-toggle': 'collapse',
						'data-parent': '#' + parent,
						'href': '#collapse-' + tabindex + tabCount,
						'aria-expanded': expanded,
						'aria-controls': 'collapse-' + tabindex + tabCount
					} );

					view.addRenderAttribute( tabContentKey, {
						'class': [ 'accordion-content' ],
					} );

					view.addInlineEditingAttributes( tabContentKey, 'advanced' );
				#>

				<div class="accordion-item panel{{{ active }}}">
					<div class="accordion-heading" role="tab" id="heading-{{{ tabindex + tabCount }}}">
					<h4 class="accordion-title">
						<a {{{ view.getRenderAttributeString( tabTitleKey ) }}} >
		
							{{{ item.title }}}
							<# if ( settings.show_icon ) { #>
							<span class="accordion-expander">
								<# if ( settings.i_add_icon ) { #>
									<i class="{{{ settings.i_icon_fontawesome.value }}}"></i>
								<# } #>
								<# if ( settings.active_add_icon ) { #>
									<i class="{{{ settings.active_icon_fontawesome.value }}}"></i>
								<# } #>
							</span>
							<# } #>
						</a>
					</h4>
					</div>
					
					<div id="collapse-{{{ tabindex + tabCount }}}" class="accordion-collapse collapse {{{ __in }}}" role="tabpanel" aria-labelledby="heading-{{{ tabindex + tabCount }}}">

					<div {{{ view.getRenderAttributeString( tabContentKey ) }}}>{{{ item.content }}}</div>
							
					</div>
				</div>
				
				<#
				} );
			}
		#>
		</div>
		<?php
	}

}
