<?php
namespace LiquidElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Schemes\Color;
use Elementor\Schemes\Typography;
use Elementor\Utils;
use Elementor\Control_Media;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Repeater;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
/**
 * Elementor heading widget.
 *
 * Elementor widget that displays an eye-catching headlines.
 *
 * @since 1.0.0
 */
class LD_Blog extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve heading widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'ld_blog';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve heading widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Liquid Blog List', 'elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve heading widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-post-list lqd-element';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the heading widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'hub-core' ];
	}

	/**
	 * Get widget keywords.
	 *
	 * Retrieve the list of keywords the widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget keywords.
	 */
	public function get_keywords() {
		return [ 'blog', 'post', 'page' ];
	}

	/**
	 * Retrieve the list of scripts the counter widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.1
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'isotope', 'packery-mode' ];
	}

    protected function get_post_type_list() {
		
		$postTypesList = array(
			'post' => __( 'Posts', 'hub-elementor-addons' ),
			'ids' => __( 'List of IDs', 'hub-elementor-addons' ),
		);

		return $postTypesList;
	}

	/**
	 * Register heading widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'blog_section',
			array(
				'label' => __( 'Blog', 'hub-elementor-addons' ),
			)
		);

        $this->add_control(
			'style',
			[
				'label' => __( 'Style', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'style01',
				'options' => [
					'style01' => __( 'Style 1', 'hub-elementor-addons' ),
					'style02' => __( 'Style 2', 'hub-elementor-addons' ),
					'style02-alt' => __( 'Style 2 Alt', 'hub-elementor-addons' ),
					'style03' => __( 'Style 3', 'hub-elementor-addons' ),
					'style04' => __( 'Style 4', 'hub-elementor-addons' ),
					'style05' => __( 'Style 5', 'hub-elementor-addons' ),
					'style06' => __( 'Style 6', 'hub-elementor-addons' ),
					'style06-alt' => __( 'Style 6 Alt', 'hub-elementor-addons' ),
					'style07' => __( 'Style 7', 'hub-elementor-addons' ),
					'style08' => __( 'Style 8', 'hub-elementor-addons' ),
					'style09' => __( 'Style 9', 'hub-elementor-addons' ),
					'style10' => __( 'Style 10', 'hub-elementor-addons' ),
					'style11' => __( 'Style 11', 'hub-elementor-addons' ),
					'style12' => __( 'Style 12', 'hub-elementor-addons' ),
					'style13' => __( 'Style 13', 'hub-elementor-addons' ),
					'style14' => __( 'Style 14', 'hub-elementor-addons' ),
					'style15' => __( 'Style 15', 'hub-elementor-addons' ),
					'style16' => __( 'Style 16', 'hub-elementor-addons' ),
					'style17' => __( 'Style 17', 'hub-elementor-addons' ),
					'style18' => __( 'Style 18', 'hub-elementor-addons' ),
					'style19' => __( 'Style 19', 'hub-elementor-addons' ),
					'style20' => __( 'Style 20', 'hub-elementor-addons' ),
					'style21' => __( 'Style 21', 'hub-elementor-addons' ),
					'style22' => __( 'Style 22', 'hub-elementor-addons' ),
					'style23' => __( 'Style 23', 'hub-elementor-addons' ),
				],
			]
		);

        $this->add_control(
			'enable_filter',
			[
				'label' => __( 'Post Filters', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'no',
				'options' => [
					'no' => __( 'Disable', 'hub-elementor-addons' ),
					'yes' => __( 'Enable', 'hub-elementor-addons' ),
				],
			]
		);

		$this->add_control(
			'filter_toggle',
			[
				'label' => __( 'Filter', 'hub-elementor-addons' ),
				'type' => Controls_Manager::POPOVER_TOGGLE,
				'label_off' => __( 'Default', 'hub-elementor-addons' ),
				'label_on' => __( 'Custom', 'hub-elementor-addons' ),
				'return_value' => 'yes',
				'condition' => [
					'enable_filter' => 'yes',
				],
			]
		);

		$this->start_popover();

		$this->add_control(
			'filter_cats',
			[
				'label' => __( 'Categories', 'hub-elementor-addons' ),
				'description' => __( 'Enter categories to display in filter bar.', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT2,
				'multiple' => true,
				'options' => $this->get_available_categories(),
			]
		);

		$this->add_control(
			'filter_normal_color',
			[
				'label' => __( 'Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .filter-list li,{{WRAPPER}} .lqd-filter-dropdown .ui-button' => 'color: {{VALUE}}',
					'{{WRAPPER}} .lqd-filter-dropdown .ui-button' => 'border-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'filter_hover_color',
			[
				'label' => __( 'Hover/Active Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .filter-list li.active, {{WRAPPER}} .filter-list li.hover,{{WRAPPER}} .lqd-filter-dropdown .ui-button:active, {{WRAPPER}} .lqd-filter-dropdown .ui-button:focus' => 'color: {{VALUE}}',
					'{{WRAPPER}} .lqd-filter-dropdown .ui-button:active, {{WRAPPER}} .lqd-filter-dropdown .ui-button:focus' => 'border-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'filter_dec_color',
			[
				'label' => __( 'Decoration Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .filters-underline li span:after, {{WRAPPER}} .filters-line-through li span:after' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'filter_lbl_all',
			[
				'label' => __( 'Label "All"', 'hub-elementor-addons' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'All', 'hub-elementor-addons' ),
				'placeholder' => __( 'All', 'hub-elementor-addons' ),
			]
		);

		$this->add_control(
			'filter_color',
			[
				'label' => __( 'Color Scheme', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					''  => __( 'Default', 'hub-elementor-addons' ),
					'filter-list-scheme-light'  => __( 'Light', 'hub-elementor-addons' ),
				],
			]
		);

		$this->add_control(
			'filter_mb',
			[
				'label' => __( 'Filter Margin Bottom', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
						'step' => 1,
					],
				],
				'default' => [
					'unit' => 'px',
				],
				'selectors' => [
					'{{WRAPPER}} .liquid-filter-items' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'filter_typography',
				'label' => __( 'Typography', 'hub-elementor-addons' ),
				'selector' => '{{WRAPPER}} .filter-list',
			]
		);
		$this->end_popover();

		$this->add_control(
			'filter_title_toggle',
			[
				'label' => __( 'Filter Title', 'hub-elementor-addons' ),
				'type' => Controls_Manager::POPOVER_TOGGLE,
				'label_off' => __( 'Default', 'hub-elementor-addons' ),
				'label_on' => __( 'Custom', 'hub-elementor-addons' ),
				'return_value' => 'yes',
				'separator' => 'after',
				'condition' => [
					'enable_filter' => 'yes',
				],
			]
		);

		$this->start_popover();
		$this->add_control(
			'filter_title',
			[
				'label' => __( 'Filter Title', 'hub-elementor-addons' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Filter by', 'hub-elementor-addons' ),
			]
		);
		
		$this->add_control(
			'filter_subtitle',
			[
				'label' => __( 'Filter Subtitle', 'hub-elementor-addons' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Subtitle', 'hub-elementor-addons' ),
				'condition' => [
					'style' => 'carousel-filterable',
				],
			]
		);

		$this->add_control(
			'link_label',
			[
				'label' => __( 'Button Label', 'hub-elementor-addons' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Subtitle', 'hub-elementor-addons' ),
				'condition' => [
					'style' => 'carousel-filterable',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'filter_title_typography',
				'label' => __( 'Typography', 'hub-elementor-addons' ),
				'selector' => '{{WRAPPER}} .liquid-filter-items-label',
			]
		);

		$this->end_popover();

		$this->add_control(
			'grid_columns',
			[
				'label' => __( 'Columns', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => '1',
				'options' => [
					'1' => __( '1 Column', 'hub-elementor-addons' ),
					'2' => __( '2 Columns', 'hub-elementor-addons' ),
					'3' => __( '3 Columns', 'hub-elementor-addons' ),
					'4' => __( '4 Columns', 'hub-elementor-addons' ),
					'custom' => __( 'Custom', 'hub-elementor-addons' ),
				],
				'condition' => array(
					'style!' => array( 
						'style05',
						'style07',
						'style14',
						'style15',
						'style18'
					),
				),
			]
		);

		$this->add_responsive_control(
			'grid_columns_custom',
			[
				'label' => __( 'Columns custom width', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'vw', 'vh' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 500,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
						'step' => 0.1,
					],
					'vw' => [
						'min' => 0,
						'max' => 100,
						'step' => 0.1,
					],
					'vh' => [
						'min' => 0,
						'max' => 100,
						'step' => 0.1,
					],
				],
				'default' => [
					'unit' => '%',
					'size' => 50,
				],
				'selectors' => [
					'{{WRAPPER}} .lqd-lp-column' => 'width: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'grid_columns' => 'custom',
					'style!' => array( 
						'style05',
						'style07',
						'style14',
						'style15',
						'style18'
					),
				]
			]
		);

		$this->add_control(
			'items_height',
			[
				'label' => __( 'Items Height', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'fullheight',
				'options' => [
					'fullheight' => __( 'Full Height', 'hub-elementor-addons' ),
					'h-pt-75' => __( '75% of Column Width (Wide)', 'hub-elementor-addons' ),
					'h-pt-100' => __( '100% of Column Width (Square)', 'hub-elementor-addons' ),
					'h-pt-125' => __( '125% of Column Width (Tall)', 'hub-elementor-addons' ),
					'h-custom' => __( 'Custom', 'hub-elementor-addons' ),
				],
				'condition' => array(
					'style' => 'style17',
				)
			]
		);

		$this->add_responsive_control(
			'items_height_custom',
			[
				'label' => __( 'Custom Height', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'vw', 'vh' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 500,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
						'step' => 0.1,
					],
					'vw' => [
						'min' => 0,
						'max' => 100,
						'step' => 0.1,
					],
					'vh' => [
						'min' => 0,
						'max' => 100,
						'step' => 0.1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 500,
				],
				'selectors' => [
					'{{WRAPPER}} .lqd-lp' => 'height: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'items_height' => 'h-custom',
					'style' => 'style17',
				]
			]
		);

		$this->add_responsive_control(
			'items_vertical_aling',
			[
				'label' => __( 'Vertical Alignment', 'hub-elementor-addons' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'start' => [
						'title' => __( 'Start', 'hub-elementor-addons' ),
						'icon' => 'eicon-h-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'hub-elementor-addons' ),
						'icon' => 'eicon-h-align-center',
					],
					'end' => [
						'title' => __( 'End', 'hub-elementor-addons' ),
						'icon' => 'eicon-h-align-right',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .lqd-lp' => 'align-items: {{VALUE}}; text-align: {{VALUE}} !important;',
					'{{WRAPPER}} .lqd-lp-inner, {{WRAPPER}} .lqd-lp-title' => 'text-align: inherit !important;',
				],
				'toggle' => true,
				'condition' => [
					'style' => ['style17', 'style22'],
				],
			]
		);

		$this->add_responsive_control(
			'items_horizontal_aling',
			[
				'label' => __( 'Horizontal Alignment', 'hub-elementor-addons' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => __( 'Top', 'hub-elementor-addons' ),
						'icon' => 'eicon-v-align-top',
					],
					'center' => [
						'title' => __( 'Middle', 'hub-elementor-addons' ),
						'icon' => 'eicon-v-align-middle',
					],
					'flex-end' => [
						'title' => __( 'Bottom', 'hub-elementor-addons' ),
						'icon' => 'eicon-v-align-bottom',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .lqd-lp-inner' => 'justify-content: {{VALUE}} !important;',
				],
				'toggle' => true,
				'condition' => [
					'style' => 'style17',
				],
			]
		);

		$this->add_control(
			'show_meta',
			[
				'label' => __( 'Post Meta', 'hub-elementor-addons' ),
				'description' => __( 'Show/Hide post meta ( tags, categories )', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'yes',
				'options' => [
					'yes'  => __( 'Show', 'hub-elementor-addons' ),
					'no'  => __( 'Hide', 'hub-elementor-addons' ),
				],
				'condition' => array(
						'style!' => array( 
								'style18',
						),
				),
			]
		);

		$this->add_control(
			'meta_type',
			[
				'label' => __( 'Meta Type', 'hub-elementor-addons' ),
				'description' => __( 'Type Of Post Meta To Show', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'tags',
				'options' => [
					'tags'  => __( 'Tags', 'hub-elementor-addons' ),
					'cats'  => __( 'Categories', 'hub-elementor-addons' ),
				],
				'condition' => array(
					'show_meta' => 'yes',
				),
			]
		);

		$this->add_control(
			'meta_style',
			[
				'label' => __( 'Meta Style', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'solid',
				'options' => [
					'solid'  => __( 'Solid', 'hub-elementor-addons' ),
					'plain'  => __( 'Plain', 'hub-elementor-addons' ),
				],
				'condition' => array(
					'show_meta' => 'yes',
					'style' => [ 'style22' ],
				),
			]
		);

		$this->add_control(
			'one_category',
			[
				'label' => __( 'Show Only One Post Meta', 'hub-elementor-addons' ),
				'description' => __( 'Enable to show one category/tag', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'yes',
				'options' => [
					'yes' => __( 'Enable', 'hub-elementor-addons' ),
					'no' => __( 'Disable', 'hub-elementor-addons' ),
				],
				'condition' => array(
					'show_meta' => 'yes',
				),
			]
		);

		$this->add_control(
			'show_read_more_button',
			[
				'label' => __( 'Read More Button', 'hub-elementor-addons' ),
				'description' => __( 'Show/Hide read more button', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'yes',
				'options' => [
					'yes'  => __( 'Show', 'hub-elementor-addons' ),
					'no'  => __( 'Hide', 'hub-elementor-addons' ),
				],
				'condition' => [
					'style' => [ 
						'style08',
						'style13',
						'style16',
						'style17',
						'style21',
					],
				],
			]
		);
        
		$this->add_control(
			'post_excerpt_length',
			[
				'label' => __( 'Excerpt Length', 'hub-elementor-addons' ),
				'description' => __( 'Set the excerpt length. Leave blank to set default ( 20 words )', 'hub-elementor-addons' ),
				'type' => Controls_Manager::TEXT,
				'placeholder' => __( 'Default 20', 'hub-elementor-addons' ),
				'condition' => array(
					'style!' => array(  
						'style01',
						'style02',
						'style02-alt',
						'style03',
						'style04',
						'style06',
						'style10',
						'style19',
					),
				),
			]
		);

		$this->add_control(
			'pagination',
			[
				'label' => __( 'Pagination', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'none',
				'options' => [
					'none' => __( 'None', 'hub-elementor-addons' ),
					'ajax' => __( 'Load More', 'hub-elementor-addons' ),
					'pagination' => __( 'Pagination', 'hub-elementor-addons' ),
				],
			]
		);

		$this->add_control(
			'ajax_trigger',
			[
				'label' => __( 'Ajax Trigger', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'click',
				'options' => [
					'click' => __( 'Click', 'hub-elementor-addons' ),
					'inview' => __( 'Inview', 'hub-elementor-addons' ),
				],
				'condition' => array(
					'pagination' => 'ajax',
				)
			]
		);

		$this->add_control(
			'ajax_text',
			array(
				'label' => __( 'Button Label', 'hub-elementor-addons' ),
				'type' => Controls_Manager::TEXT,
				'condition' => array(
					'pagination' => 'ajax',
				),
			)
		);

		$this->add_control(
			'post_type',
			[
				'label' => __( 'Data source', 'hub-elementor-addons' ),
				'description' => __( 'Select content type for your grid.', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'post',
				'options' => self::get_post_type_list(),
			]
		);

		$this->add_control(
			'posts_per_page',
			array(
				'label' => __( 'Total items', 'hub-elementor-addons' ),
				'description' => esc_html__( 'Set max limit for items in grid or enter -1 to display all (limited to 1000).', 'hub-elementor-addons' ),
				'type' => Controls_Manager::TEXT,
				'default' => '10',
				'condition' => array(
					'post_type!' => array( 'ids' )
				),
			)
		);

        $this->add_control(
			'taxonomies',
			[
				'label' => __( 'Narrow data source', 'hub-elementor-addons' ),
				'description' => __( 'Enter categories.', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT2,
				'multiple' => true,
				'options' => $this->get_available_categories(),
                'condition' => [
                    'post_type' => 'post',
				],
            ]
		);

        $this->add_control(
			'include',
			[
				'label' => __( 'Include only', 'hub-elementor-addons' ),
				'description' => __( 'Add posts, pages, etc. by title.', 'hub-elementor-addons' ),
				'type' => Controls_Manager::TEXT,
                'placeholder' => __( 'Add posts, pages, etc. by title.', 'hub-elementor-addons' ),
                'condition' => array(
                    'post_type' => 'ids',
                )
            ]
		);
        $this->end_controls_section();

        // Columns Spacing
        $this->start_controls_section(
			'columns_spacing_section',
			array(
				'label' => __( 'Columns Spacing', 'hub-elementor-addons' ),
			)
		);

		$this->add_responsive_control(
			'columns_gap',
			[
				'label' => __( 'Columns Spacing', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 50,
						'step' => 1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 15,
				],
				'selectors' => [
					'{{WRAPPER}} .lqd-lp-row' => 'margin-inline-start: -{{SIZE}}{{UNIT}};margin-inline-end: -{{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .lqd-lp-column' => 'padding-inline-start: {{SIZE}}{{UNIT}};padding-inline-end: {{SIZE}}{{UNIT}};',
				],
			]
		);

        $this->add_responsive_control(
			'bottom_gap',
			[
				'label' => __( 'Bottom Spacing', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
						'step' => 1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 30,
				],
				'selectors' => [
					'{{WRAPPER}} .lqd-lp-column' => 'margin-bottom: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .lqd-lp-column:not(:last-child) .lqd-lp-style-22' => 'padding-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);
        $this->end_controls_section();

        // Style Section
        $this->start_controls_section(
			'style_section',
			[
				'label' => __( 'Style', 'hub-elementor-addons' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'label' => __( 'Title Typography', 'hub-elementor-addons' ),
				'selector' => '{{WRAPPER}} .lqd-lp-title',
			]
		);

        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'content_typography',
				'label' => __( 'Content Typography', 'hub-elementor-addons' ),
				'selector' => '{{WRAPPER}} .lqd-lp-excerpt p',
			]
		);

        $this->add_responsive_control(
			'title_margin',
			[
				'label' => __( 'Title Margin', 'hub-elementor-addons' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .lqd-lp-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}!important;',
				],
			]
		);

        $this->add_control(
			'title_color',
			[
				'label' => __( 'Title Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-lp-title a' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'title_hover_color',
			[
				'label' => __( 'Title Hover Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-lp .lqd-lp-title a:hover' => 'color: {{VALUE}}',
					'{{WRAPPER}} .lqd-lp:hover .lqd-lp-title a' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'underline_color',
			[
				'label' => __( 'Underline Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-lp h2 .split-inner:before' => 'background: {{VALUE}}',
				],
                'condition' => array(
                    'style' => 'style18',
                )
			]
		);

        $this->add_control(
			'hover_underline_color',
			[
				'label' => __( 'Underline Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-lp h2 .split-inner:after' => 'background: {{VALUE}}',
				],
                'condition' => array(
                    'style' => array(
                        'style13',
						'style18',
						'style19'
                    ),
                )
			]
		);

		$this->add_control(
			'excerpt_color',
			[
				'label' => __( 'Excerpt Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-lp-excerpt' => 'color: {{VALUE}}',
				],
				'condition' => array(
					'style' => array(
					'style08',
					'style09',
					'style11',
					'style12',
					'style13',
					'style15',
					'style16',
					'style20',
					'style22',
					),
				)
			]
		);
        
        $this->add_control(
			'btn_color',
			[
				'label' => __( 'Button Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-lp-read-more' => 'color: {{VALUE}}',
				],
				'condition' => array(
					'style' => array(
						'style16',
						'style17',
					),
				)
			]
		);

		$this->add_control(
			'hover_btn_color',
			[
				'label' => __( 'Hover 	Button Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}:hover .lqd-lp-read-more' => 'color: {{VALUE}}',
				],
				'condition' => array(
					'style' => array(
						'style16',
						'style17',
					),
				)
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'bg_color',
				'label' => __( 'Background Color', 'hub-elementor-addons' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .lqd-lp',
				'condition' => array(
					'style' => array(
						'style21'
					),
				)
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'overlay_color',
				'label' => __( 'Background Color', 'hub-elementor-addons' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .lqd-lp .lqd-lp-content-bg, {{WRAPPER}} .lqd-lp .lqd-lp-img .lqd-overlay',
				'condition' => array(
					'style' => array(
						'style02-alt',
						'style03',
						'style09',
						'style10',
						'style11',
						'style17',
						'style21'
					),
				)
			]
		);

		$this->end_controls_section();

		// Pagination Styling
		$this->start_controls_section(
			'ajax_btn_colors_section',
			array(
				'label' => __( 'Pagination Button Styling', 'hub-elementor-addons' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'pagination' => [ 'ajax' ]
				]
			)
		);

		$this->start_controls_tabs(
			'pagination_style_tabs'
		);

		// Normal state
		$this->start_controls_tab(
			'pagination_style_normal_tab',
			[
				'label' => __( 'Normal', 'hub-elementor-addons' ),
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'pagination_btn_bg',
				'label' => __( 'Button Background', 'hub-elementor-addons' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .ld-ajax-loadmore',
			]
		);

		$this->add_control(
			'pagination_btn_color',
			[
				'label' => __( 'Button text color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ld-ajax-loadmore' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_tab();

		// Hovver state
		$this->start_controls_tab(
			'pagination_style_hover_tab',
			[
				'label' => __( 'Hover', 'hub-elementor-addons' ),
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'hover_pagination_btn_bg',
				'label' => __( 'Button Background', 'hub-elementor-addons' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .ld-ajax-loadmore:hover',
			]
		);

		$this->add_control(
			'hover_pagination_btn_color',
			[
				'label' => __( 'Button text color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ld-ajax-loadmore:hover' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_control(
			'ajax_btn_width',
			[
				'label' => __( 'Ajax Button Width', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => __( 'Default', 'hub-elementor-addons' ),
					'btn-block' => __( 'Fullwidth', 'hub-elementor-addons' ),
				],
				'condition' => array(
					'pagination' => 'ajax',
				),
			]
		);

		$this->end_controls_section();

		// Data Section
		$this->start_controls_section(
			'data_section',
			[
				'label' => __( 'Data', 'hub-elementor-addons' ),
			]
		);

        $this->add_control(
			'orderby',
			[
				'label' => __( 'Order by', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => [
					'date' => __( 'Date', 'hub-elementor-addons' ),
					'ID' => __( 'Order by post ID', 'hub-elementor-addons' ),
					'author' => __( 'Author', 'hub-elementor-addons' ),
					'title' => __( 'title', 'hub-elementor-addons' ),
					'modified' => __( 'Last modified date', 'hub-elementor-addons' ),
					'parent' => __( 'Post/page parent ID', 'hub-elementor-addons' ),
					'comment_count' => __( 'Number of comments', 'hub-elementor-addons' ),
					'menu_order' => __( 'Menu order/Page Order', 'hub-elementor-addons' ),
					'meta_value' => __( 'Meta value', 'hub-elementor-addons' ),
					'meta_value_num' => __( 'Meta value number', 'hub-elementor-addons' ),
					'rand' => __( 'Random order', 'hub-elementor-addons' ),
				],
                'condition' => array(
                    'post_type!' => array(
                        'ids',
						'custom'
                    ),
                ),
			]
		);

        $this->add_control(
			'order',
			[
				'label' => __( 'Sort Order', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => [
					'DESC' => __( 'Descending', 'hub-elementor-addons' ),
					'ASC' => __( 'Ascending', 'hub-elementor-addons' ),
				],
                'condition' => array(
                    'post_type!' => array(
                        'ids',
						'custom'
                    ),
                ),
			]
		);

        $this->add_control(
			'meta_key',
			[
				'label' => __( 'Meta key', 'hub-elementor-addons' ),
				'type' => Controls_Manager::TEXT,
				'description' => __( 'Input meta key for grid ordering.', 'hub-elementor-addons' ),
                'condition' => array(
                    'orderby' => array(
                        'meta_value',
						'meta_value_num',
                    ),
                ),
			]
		);

        $this->add_control(
			'offset',
			[
				'label' => __( 'Offset', 'hub-elementor-addons' ),
				'type' => Controls_Manager::TEXT,
				'placeholder' => __( 'Number of grid elements to displace or pass over.', 'hub-elementor-addons' ),
                'condition' => array(
                    'post_type!' => array(
                        'ids',
						'custom'
                    ),
                ),
			]
		);

        $this->add_control(
			'exclude',
			[
				'label' => __( 'Exclude', 'hub-elementor-addons' ),
				'type' => Controls_Manager::TEXT,
				'placeholder' => __( 'Exclude posts, pages, etc. by title.', 'hub-elementor-addons' ),
                'condition' => array(
                    'post_type!' => array(
                        'ids',
						'custom'
                    ),
                ),
			]
		);
        
        $this->end_controls_section();

	}

	/**
	 * Render heading widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		
		$atts = $this->get_settings_for_display();

		$style = $atts['style'];
		$items_height = $atts['items_height'];
		$filter_id = 'blog-filter-' . $this->get_id_int();
		$section_id = uniqid( 'heading-id' );
		$ajax_trigger = $atts['ajax_trigger'];

		$filter_size = $filter_decoration = $filter_transformation = $filter_weight = $filter_title_size = $filter_title_weight = $filter_title_transformation = '';

		$carousel_heading = '';
		if( !empty( $atts['carousel_heading'] ) ) {
			$carousel_heading = '<header class="fancy-title" id="' . $section_id . '"><h2 class="font-weight-bold">'. esc_html( $atts['carousel_heading'] ) . '</h2></header>';
		}

		$ajax_wrapper = '';

		$unique_id = 'blog-id-' . $this->get_id_int();
		$ajax_wrapper = '.' . $unique_id;

		// check
		$located = locate_template( "templates/blog/tmpl-$style.php" );
		if ( ! file_exists( $located ) ) {
			return;
		}

		$i = 0;

		echo '<div class="lqd-lp-grid ' . $this->get_id() . ' ' . $unique_id . ' ">';

		// Include filter
		if( 'yes' === $atts['enable_filter'] ) {
			$filter_located = locate_template( 'templates/blog/partial-filters.php' );
			include $filter_located;
		}

		// Build Query
		$GLOBALS['wp_query'] = new \WP_Query( $this->build_query() );
		$before = $after = '';
			
			if( 'style05' === $style || 'style07' === $style ) {
				echo '<div class="lqd-lp-row row d-flex flex-wrap" data-liquid-masonry="true" data-masonry-options=\'{ "filtersID": "#' . $filter_id . '","itemSelector": ".lqd-lp-column" }\'>';
				$after  = '</div>';
			}
			elseif( 'style14' === $style ) {
				echo '<div class="lqd-lp-row row d-flex flex-wrap" data-liquid-masonry="true" data-masonry-options=\'{ "itemSelector": ".lqd-lp-column" }\'>';
				$after  = '</div>';
			}
			else {
				if( 'yes' === $atts['enable_filter'] ) {
					echo '<div class="lqd-lp-row row d-flex flex-wrap" data-liquid-masonry="true" data-masonry-options=\'{ "filtersID": "#' . $filter_id . '","itemSelector": ".lqd-lp-column" }\'>';
				} else {
					echo '<div class="lqd-lp-row row d-flex flex-wrap">';
				}
				$after  = '</div>';
			}

			
			while( have_posts() ): the_post();

				$before = '<div class="lqd-lp-column ' . $this->get_grid_class() . ' ' . $this->entry_term_classes() . '">';

				$post_classes = array( 'lqd-lp' );
				if( 'style01' === $style ) {
					$post_classes[] = 'lqd-lp-style-1 pos-rel';
				}
				elseif( 'style02' === $style ) {
					$post_classes[] = 'lqd-lp-style-2 d-flex flex-column justify-content-between pos-rel round overflow-hidden p-5';
				}
				elseif( 'style02-alt' === $style ) {
					$post_classes[] = 'lqd-lp-style-2 lqd-lp-style-2-alt d-flex flex-column justify-content-between pos-rel round overflow-hidden p-5';
				}
				elseif( 'style03' === $style ) {
					$post_classes[] = 'lqd-lp-style-3 pos-rel';
				}
				elseif( 'style04' === $style ) {
					$post_classes[] = 'lqd-lp-style-4 lqd-lp-title-15 pos-rel d-flex flex-wrap align-items-center';
				}
				elseif( 'style05' === $style ) {
					$post_classes[] = 'lqd-lp-style-5 lqd-lp-title-34 pos-rel d-flex flex-wrap align-items-center';
					$before = '<div class="lqd-lp-column col-md-12 ' . $this->entry_term_classes() . '">';
				}
				elseif( 'style06' === $style ) {
					$post_classes[] = 'lqd-lp-style-6 lqd-lp-hover-img-zoom pos-rel round overflow-hidden';
				}
				elseif( 'style06-alt' === $style ) {
					$post_classes[] = 'lqd-lp lqd-lp-style-6 lqd-lp-style-6-alt lqd-lp-title-20 lqd-lp-hover-img-zoom lqd-lp-hover-img-zoom-out pos-rel round overflow-hidden';
				}
				elseif( 'style07' === $style ) {
					$post_classes[] = 'lqd-lp-style-7 lqd-lp-title-34 pos-rel lqd-lp-hover-img-zoom';
					$before = '<div class="lqd-lp-column col-md-12 ' . $this->entry_term_classes() . '">';
				}
				elseif( 'style08' === $style ) {
					$post_classes[] = 'lqd-lp-style-8 p-5 pos-rel round overflow-hidden';
				}
				elseif( 'style09' === $style ) {
					$post_classes[] = 'lqd-lp-style-9 pos-rel d-flex flex-wrap';
				}
				elseif( 'style10' === $style  ) {
					$post_classes[] = 'lqd-lp-style-10 lqd-lp-img-cover pos-rel d-flex flex-wrap round overflow-hidden h-pt-80 lqd-lp-hover-img-zoom';
				}
				elseif( 'style11' === $style  ) {
					$post_classes[] = 'lqd-lp-style-11 lqd-lp-img-cover lqd-lp-title-27 pos-rel d-flex flex-wrap round overflow-hidden h-pt-95';
				}
				elseif( 'style12' === $style  ) {
					$post_classes[] = 'lqd-lp-style-12 pos-rel overflow-hidden border-radius-7 p-4 px-md-5';
				}
				elseif( 'style13' === $style  ) {
					$post_classes[] = 'lqd-lp lqd-lp-style-13 pos-rel';
				}
				elseif( 'style14' === $style  ) {
					$i++;
					if( 1 === $i ) {
						$post_classes[] = 'lqd-lp lqd-lp-style-14 lqd-lp-img-cover lqd-lp-hover-img-zoom lqd-lp-title-36 pos-rel d-flex flex-wrap round overflow-hidden h-pt-60';
						$before = '<div class="lqd-lp-column col-xs-12 col-md-8 ' . $this->entry_term_classes() . '">';
					}
					else {
						$post_classes[] = 'lqd-lp lqd-lp-style-14 lqd-lp-img-cover lqd-lp-hover-img-zoom lqd-lp-title-20 pos-rel d-flex flex-wrap round overflow-hidden h-pt-60';
						$before = '<div class="lqd-lp-column col-xs-12 col-md-4 ' . $this->entry_term_classes() . '">';
					}
				}
				elseif( 'style16' === $style  ) {
					$post_classes[] = 'lqd-lp lqd-lp-style-16 pos-rel';
				}
				elseif( 'style17' === $style  ) {
					$post_classes[] = 'lqd-lp lqd-lp-style-17 lqd-lp-img-cover lqd-lp-title-40 pos-rel d-flex flex-wrap round overflow-hidden ' . $items_height . '';
				}
				elseif( 'style18' === $style  ) {
					$post_classes[] = 'lqd-lp lqd-lp-style-18 d-md-block';
				}
				elseif( 'style19' === $style  ) {
					$post_classes[] = 'lqd-lp lqd-lp-style-19 pos-rel';
				}
				elseif( 'style20' === $style  ) {
					$post_classes[] = 'lqd-lp lqd-lp-style-20 lqd-lp-hover-img-zoom pos-rel';
				}
				elseif( 'style21' === $style  ) {
					$post_classes[] = 'lqd-lp lqd-lp-style-21 pos-rel d-flex flex-wrap';
				}
				elseif( 'style22' === $style  ) {
					$post_classes[] = 'lqd-lp lqd-lp-style-22 lqd-lp-title-34 pos-rel lqd-lp-hover-img-zoom';
				}
				elseif( 'style23' === $style  ) {
					$post_classes[] = 'lqd-lp lqd-lp-style-23 lqd-lp-title-22 lqd-lp-hover-img-zoom lqd-lp-hover-img-zoom-out pos-rel';
				}

				$post_classes = join( ' ', get_post_class( $post_classes, get_the_ID() ) );

				$attributes = array(
					'id'    => 'post-' . get_the_ID(),
					'class' => $post_classes
				);
				
				echo $before;
				
				printf( '<article%s>', ld_helper()->html_attributes( $attributes ) );

					if( 'quote' === get_post_format() ) {
						$quote_located = locate_template( 'templates/blog/format-quote.php' );
						include $quote_located;
					}
					else {
						include $located;
					}

				echo '</article>';

				echo $after;
				
			endwhile;
			
			if( 'carousel' == $style ) {
				echo '</div></div>';
			}
			echo '</div><!--/ .row -->';
			
			// Pagination
			if( 'pagination' === $atts['pagination'] ) {
				
				$max = $GLOBALS['wp_query']->max_num_pages;

				// Set up paginated links.
				$links = paginate_links( array(
					'type' => 'array',
					'prev_next' => true,
					'prev_text' => '<span aria-hidden="true">' . wp_kses_post( __( '<i class="fa fa-angle-left"></i>', 'landinghub-core' ) ) . '</span>',
					'next_text' => '<span aria-hidden="true">' . wp_kses_post( __( '<i class="fa fa-angle-right"></i>', 'landinghub-core' ) ) . '</span>',
				) );

				if( !empty( $links ) ) {
					printf( '<div class="page-nav"><nav aria-label="Page navigation"><ul class="pagination"><li>%s</li></ul></nav></div>', join( "</li>\n\t<li>", $links ) );
				}
			}
			
			if( in_array( $atts['pagination'], array( 'ajax' ) ) && $url = get_next_posts_page_link( $GLOBALS['wp_query']->max_num_pages ) ) {
				$hash = array(
					'ajax' => 'btn btn-md ajax-load-more',
				);

				$attributes = array(
					'href' => add_query_arg( 'ajaxify', '1', $url ),
					'rel' => 'nofollow',
					'data-ajaxify' => true,
					'data-ajaxify-options' => json_encode( array(
						'wrapper' => '.lqd-lp-grid' . $ajax_wrapper . ' > .lqd-lp-row',
						'items'   => '> .lqd-lp-column',
						'trigger' => $ajax_trigger,
					) )
				);

				echo '<div class="liquid-pf-nav ld-pf-nav-ajax"><div class="page-nav text-center"><nav aria-label="' . esc_attr__( 'Page navigation', 'landinghub-core' ) . '">';
				switch( $atts['pagination'] ) {

					case 'ajax':
						$ajax_text = ! empty( $atts['ajax_text'] ) ? esc_html( $atts['ajax_text'] ) : esc_html__( 'Load more', 'landinghub-core' );
						$attributes['class'] = 'elementor-button btn ld-ajax-loadmore ' . $atts['ajax_btn_width'];
						printf( '<a%2$s><span><span class="static">%1$s</span><span class="loading"><span class="dots"><span></span><span></span><span></span></span><span class="text-uppercase lts-sp-1">' . esc_html__( 'Loading', 'landinghub-core' ) . '</span></span><span class="all-loaded">' . esc_html__( 'All items loaded', 'landinghub-core' ) . ' <i class="lqd-icn-ess icon-ion-ios-checkmark"></i></span></span></a>', $ajax_text, ld_helper()->html_attributes( $attributes ), $url );
						break;
				}

				echo '</nav></div></div>';
			}

			wp_reset_query();

		echo '</div><!--/ .lqd-lp-grid -->';
				
	}

	private function get_available_categories() {

		$cats = get_categories( array(
			'orderby' => 'name',
			'order'   => 'ASC'
		));

		$options = [];

		foreach ( $cats as $cat ) {
			$options[ $cat->cat_ID ] = $cat->name;
		}
		
		return $options;

	}

	protected function overlay_link() {
		
		$format = get_post_format();
		$url = 'link' == $format ? liquid_helper()->get_option( 'post-link-url' ) : get_permalink();
		$target = 'link' == $format ? 'target="_blank"' : '';
		
		echo '<a ' . $target . ' href="' . esc_url( $url ) . '" class="lqd-lp-overlay-link lqd-overlay z-index-2"></a>';

	}

	// https://codex.wordpress.org/Making_Custom_Queries_using_Offset_and_Pagination
	// check it
	protected function build_query() {

		extract( $this->get_settings_for_display() );
		$settings = array();
		$settings['post_status'] = 'publish';

		if( 'custom' === $post_type && ! empty( $custom_query ) ) {
			$query = html_entity_decode(  $custom_query , ENT_QUOTES, 'utf-8' );
			$settings = wp_parse_args( $query );
		}
		elseif( 'ids' === $post_type ) {

			if ( empty( $include ) ) {
				$include = - 1;
			}

			$incposts = wp_parse_id_list( $include );
			$settings = array(
				'post__in' => $incposts,
				'posts_per_page' => count( $incposts ),
				'post_type' => 'any',
				'orderby' => 'post__in',
			);
		}
		else {
			$settings = array(
				'posts_per_page' => isset( $posts_per_page ) ? (int) $posts_per_page : 100,
				'offset'         => $offset,
				'orderby' => $orderby,
				'order' => $order,
				'meta_key' => in_array( $orderby, array(
					'meta_value',
					'meta_value_num',
				) ) ? $meta_key : '',
				'post_type' => $post_type,
				'ignore_sticky_posts' => true,
			);

			if( $exclude ) {
				$settings['post__not_in'] = wp_parse_id_list( $exclude );
			}

			/*if( intval( $offset ) ) {
				$settings['no_found_rows'] = intval( $offset );
			}*/

			if( 'none' === $pagination ) {
				$settings['no_found_rows'] = true;
			}
			else {
				$settings['paged'] = ld_helper()->get_paged();
			}

			if ( $settings['posts_per_page'] < 1 ) {
				$settings['posts_per_page'] = 1000;
			}

			if ( ! empty( $taxonomies ) ) {

				$terms = get_terms( array(
					'hide_empty' => false,
					'include' => $taxonomies,
				) );
				$settings['tax_query'] = array();
				$tax_queries = array(); // List of taxnonimes
				foreach ( $terms as $t ) {
					if ( ! isset( $tax_queries[ $t->taxonomy ] ) ) {
						$tax_queries[ $t->taxonomy ] = array(
							'taxonomy' => $t->taxonomy,
							'field' => 'id',
							'terms' => array( $t->term_id ),
							'relation' => 'IN',
						);
					} else {
						$tax_queries[ $t->taxonomy ]['terms'][] = $t->term_id;
					}
				}
				$settings['tax_query'] = array_values( $tax_queries );
				$settings['tax_query']['relation'] = 'OR';
			}
		}

		return $settings;
	}

	protected function get_grid_class() {

		$column = $this->get_settings_for_display('grid_columns');
		$hash = array(
			'1' => '12',
			'2' => '6',
			'3' => '4',
			'4' => '3',
			'6' => '2'
		);

		if ( ! empty( $hash[ $column ] ) ) {
			$col = $hash[ $column ];
			if ( $col !== '12' ) {
				$col .= ' col-sm-6';
			}
			return sprintf( 'col-md-%s', $col );
		}

		return 'col-md-12';

	}

	/**
	 * [entry_term_classes description]
	 * @method entry_term_classes
	 * @return [type]             [description]
	 */
	protected function entry_term_classes() {

		$postcats = get_the_category();
		$cat_slugs = array();
		if ( count( $postcats ) > 0 ) :
			foreach ( $postcats as $postcat ):
				$cat_slugs[] = 	$postcat->slug;
			endforeach;
		endif;
		
		return implode( ' ', $cat_slugs );
		
	}

	protected function entry_title( $classes = '' ) {
		
		$style = $this->get_settings_for_display('style');
		
		$format = get_post_format();
		if ( 'link' !== $format && is_single() ) {
			the_title( '<h1 class="entry-title">', '</h1>' );
			return;
		}

		$url = 'link' == $format ? liquid_helper()->get_option( 'post-link-url' ) : get_permalink();
		$target = 'link' == $format ? 'target="_blank"' : '';
		
		the_title( sprintf( '<h2 class="entry-title lqd-lp-title %s"><a ' . $target . ' href="%s" rel="bookmark">', $classes, esc_url( $url ) ), '</a></h2>' );

		
	}

	protected function entry_tags_color( $term_id ){

		if ( $color = get_term_meta( $term_id, 'lqd_category_color', true ) ){
			$color = esc_attr( ' style=--color-primary:#' . $color  );
			return $color;
		}

	}

	protected function entry_tags( $classes = '' ) {

		$settings = $this->get_settings_for_display();
		
		$show_meta = $settings['show_meta'];
		if( 'no' === $show_meta ) {
			return;
		}
		
		global $post;
		
		$out = '';
		
		$meta_type    = $settings['meta_type'];
		$one_category = $settings['one_category'];
		$style = $settings['style'];
		
		$tags_list = wp_get_post_tags( $post->ID );
		
		
		$rel = 'rel="tag"';
		$color = '';
		
		if( 'cats' === $meta_type ) {
			$tags_list = get_the_category( $post->ID );	
			$rel = 'rel="category"';
		}		
		
		$before       = '<ul class="lqd-lp-cat ' . esc_attr( $classes ) . '">';
		$after        = '</ul>';
		$before_link  = '<li>';
		$after_link   = '</li>';
		$before_label = '';
		$after_label  = '';
		
		if ( $tags_list ) {			
			$out .= $before;
			if( 'yes' === $one_category ) {
				if( 'style05' == $settings['style'] ) {
					$out .= '<li class="border-radius-5"><a class="lh-1" href="' . get_category_link( $tags_list['0']->term_id ) . '" ' . $rel . $this->entry_tags_color($tags_list['0']->term_id) . '>' . $before_label . esc_html( $tags_list['0']->name ) . $after_label . '</a></li>';
				}
				elseif( 'style01' == $settings['style'] || 'style02' == $settings['style'] || 'style02-alt' == $settings['style'] || 'style06' == $settings['style'] || 'style06-alt' == $settings['style'] || 'style11' == $settings['style'] || 'style15' == $settings['style'] || 'style23' == $settings['style'] ) {
					$out .= '<li><a class="lh-15 circle" href="' . get_category_link( $tags_list['0']->term_id ) . '" ' . $rel . $this->entry_tags_color($tags_list['0']->term_id) . '>' . $before_label . esc_html( $tags_list['0']->name ) . $after_label . '</a></li>';
				}
				elseif( 'style10' == $settings['style'] ) {
					$out .= '<li><a class="lh-15 round" href="' . get_category_link( $tags_list['0']->term_id ) . '" ' . $rel . $this->entry_tags_color($tags_list['0']->term_id) . '>' . $before_label . esc_html( $tags_list['0']->name ) . $after_label . '</a></li>';
				}
				else {
					$out .= '<li><a href="' . get_category_link( $tags_list['0']->term_id ) . '" ' . $rel . $this->entry_tags_color($tags_list['0']->term_id) . '>' . $before_label . esc_html( $tags_list['0']->name ) . $after_label . '</a></li>';
				}
				
			}
			else {
				foreach( $tags_list as $tag ) {
					if( 'style05' == $settings['style'] ) {
						$out .= '<li class="border-radius-5"><a href="' . get_category_link( $tag->term_id ) . '" ' . $rel . $this->entry_tags_color($tag->term_id) . '>' . $before_label . esc_html( $tag->name ) . $after_label . '</a></li>';
					}
					elseif( 'style01' == $settings['style'] || 'style02' == $settings['style'] || 'style02-alt' == $settings['style'] || 'style06' == $settings['style'] || 'style06-alt' == $settings['style'] || 'style11' == $settings['style'] || 'style15' == $settings['style'] || 'style23' == $settings['style'] ) {
						$out .= '<li><a class="circle" href="' . get_category_link( $tag->term_id ) . '" ' . $rel . $this->entry_tags_color($tag->term_id) . '>' . $before_label . esc_html( $tag->name ) . $after_label . '</a></li>';
					}
					elseif( 'style10' == $settings['style'] ) {
						$out .= '<li><a class="round" href="' . get_category_link( $tag->term_id ) . '" ' . $rel . $this->entry_tags_color($tag->term_id) . '>' . $before_label . esc_html( $tag->name ) . $after_label . '</a></li>';
					}
					else {
						$out .= '<li><a href="' . get_category_link( $tag->term_id ) . '" ' . $rel . $this->entry_tags_color($tag->term_id) . '>' . $before_label . esc_html( $tag->name ) . $after_label . '</a></li>';
					}
				}				
			}
			$out .= $after;
		}
		
		if( $out ) {
			printf( '<div><span class="screen-reader-text">%1$s </span>%2$s</div>',
				_x( 'Tags', 'Used before tag names.', 'landinghub-core' ),
				$out
			);
		}
		
	}

	protected function entry_thumbnail( $size = 'liquid-thumbnail', $attr = '', $background = false ) {
		
		//Check
		if ( post_password_required() || is_attachment() ) {
			return;
		}
		$figure_classnames = '';
		
		if( 'rounded' === $this->get_settings_for_display( 'style' ) ) {
			$figure_classnames = 'rounded';
		}
		elseif( 'square' === $this->get_settings_for_display( 'style' ) ) {
			$figure_classnames = 'round';
		}		
		
		$src = wp_get_attachment_image_src( get_post_thumbnail_id(), 'full', false );
		$src = liquid_get_resized_image_src( $src, $size );		
		
		$format = get_post_format();
		$style = $this->get_settings_for_display( 'style' );
		$url = 'link' == $format ? liquid_helper()->get_option( 'post-link-url' ) : get_permalink();
		$target = 'link' == $format ? 'target="_blank"' : '';
		
		if( has_post_thumbnail() ) {

			if( 'style01' == $this->get_settings_for_display( 'style' ) ) {
				printf( '<div class="lqd-lp-img"><figure class="border-radius-2 overflow-hidden">' );
				liquid_the_post_thumbnail( 'liquid-style1-lb', array( 'class' => 'w-100'  ), true );
				echo '</figure></div>';
			}
			elseif( 'style02-alt' == $this->get_settings_for_display( 'style' ) ) {
				printf( '<div class="lqd-lp-img lqd-overlay w-100 h-100"><figure class="w-100 h-100 overflow-hidden">' );	
				liquid_the_post_thumbnail( 'liquid-style3-lb', array( 'class' => 'w-100' ), true );
				echo '<div class="lqd-lp-content-bg lqd-overlay"></div>';
				echo '</figure></div>';
			}
			elseif( 'style03' == $this->get_settings_for_display( 'style' ) ) {
				printf( '<div class="lqd-lp-img mb-5"><figure class="pos-rel overflow-hidden border-radius-5">' );	
				liquid_the_post_thumbnail( 'liquid-style1-lb', array( 'class' => 'w-100' ), true );
				echo '<div class="lqd-overlay align-items-center justify-content-center">
			<div class="lqd-overlay lqd-overlay-bg"></div><!-- /.lqd-overlay lqd-overlay-bg -->
			<i class="lqd-icn-ess icon-md-arrow-forward"></i>
		</div><!-- /.lqd-overlay align-items-center justify-content-center -->';
				echo '</figure></div>';
			}
			elseif( 'style04' == $this->get_settings_for_display( 'style' ) ) {
				printf( '<div class="lqd-lp-img w-25"><figure class="pos-rel overflow-hidden border-radius-5">' );	
				liquid_the_post_thumbnail( 'liquid-style4-lb', array( 'class' => 'w-100' ), true );
				echo '</figure></div>';
			}
			elseif( 'style05' == $this->get_settings_for_display( 'style' ) ) {
				printf( '<div class="lqd-lp-img mb-5 mb-md-0 w-md-50"><figure class="overflow-hidden border-radius-5">' );	
				liquid_the_post_thumbnail( 'liquid-style5-lb', array( 'class' => 'w-100' ), true );
				echo '</figure></div>';
			}
			elseif( 'style06' == $this->get_settings_for_display( 'style' ) ) {
				printf( '<figure>' );	
				liquid_the_post_thumbnail( 'liquid-style6-lb', array( 'class' => 'w-100' ), true );
				echo '</figure>';
			}
			elseif( 'style06-alt' == $this->get_settings_for_display( 'style' ) || 'style23' == $this->get_settings_for_display( 'style' ) ) {
				printf( '<figure>' );	
				liquid_the_post_thumbnail( 'liquid-style6-alt-lb', array( 'class' => 'w-100' ), true );
				echo '</figure>';
			}
			elseif( 'style07' == $this->get_settings_for_display( 'style' ) ) {
				printf( '<div class="lqd-lp-img overflow-hidden border-radius-5 mb-6"><figure>' );	
				liquid_the_post_thumbnail( 'liquid-style5-lb', array( 'class' => 'w-100' ), true );
				echo '</figure></div>';
			}
			elseif( 'style09' == $this->get_settings_for_display( 'style' ) ) {
				liquid_the_post_thumbnail( 'liquid-style9-lb', array( 'class' => 'w-100' ), true );
			}
			elseif( 'style10' == $this->get_settings_for_display( 'style' ) ) {
				printf( '<div class="lqd-lp-img lqd-overlay"><figure class="pos-rel bg-cover bg-center w-100">' );	
				liquid_the_post_thumbnail( 'liquid-style5-lb', array( 'class' => 'w-100' ), true );
				echo '</figure></div>';
			}
			elseif( 'style11' == $this->get_settings_for_display( 'style' ) ) {
				printf( '<div class="lqd-lp-img lqd-overlay"><figure class="pos-rel bg-cover bg-center w-100">' );	
				liquid_the_post_thumbnail( 'liquid-style5-lb', array( 'class' => 'w-100' ), true );
				echo '</figure></div>';
			}
			elseif( 'style13' == $this->get_settings_for_display( 'style' ) ) {
				printf( '<figure class="pos-rel overflow-hidden">' );	
				liquid_the_post_thumbnail( 'liquid-style13-lb', array( 'class' => 'w-100' ), true );
				echo '</figure>';
			}
			elseif( 'style14' == $this->get_settings_for_display( 'style' ) ) {
				printf( '<figure class="pos-rel bg-cover bg-center w-100">' );	
				liquid_the_post_thumbnail( 'liquid-style5-lb', array( 'class' => 'w-100' ), true );
				echo '</figure>';
			}
			elseif( 'style17' == $this->get_settings_for_display( 'style' ) ) {
				printf( '<figure class="pos-rel bg-cover bg-center w-100">' );	
				liquid_the_post_thumbnail( 'liquid-style18-lb', array( 'class' => 'w-100' ), true );
				echo '</figure>';
			}
			elseif( 'style16' == $this->get_settings_for_display( 'style' ) ) {
				printf( '<figure class="pos-rel bg-cover bg-center w-100">' );	
				liquid_the_post_thumbnail( $size, array( 'class' => 'w-100' ), true );
				echo '</figure>';
			}
			elseif( 'style18' == $this->get_settings_for_display( 'style' ) ) {
				printf( '<figure>' );	
				liquid_the_post_thumbnail( 'liquid-style18-lb', array( 'class' => 'w-100' ), true );
				echo '</figure>';
			}
			elseif( 'style19' == $this->get_settings_for_display( 'style' ) ) {
				printf( '<figure class="pos-rel overflow-hidden">' );	
				liquid_the_post_thumbnail( 'liquid-style1-lb', array( 'class' => 'w-100' ), true );
				echo '</figure>';
			}
			elseif( 'style20' == $this->get_settings_for_display( 'style' ) ) {
				printf( '<figure class="pos-rel">' );	
				liquid_the_post_thumbnail( 'liquid-style1-lb', array( 'class' => 'w-100' ), true );
				echo '</figure>';
			}
			elseif( 'style21' == $this->get_settings_for_display( 'style' ) ) {
				printf( '<figure class="pos-abs pos-tl w-100 h-100">' );
				liquid_the_post_thumbnail( 'liquid-style1-lb', array( 'class' => 'w-100' ), true );
				echo '<div class="lqd-overlay align-items-center justify-content-center"><i class="lqd-icn-ess icon-md-arrow-forward"></i></div><!-- /.lqd-overlay align-items-center justify-content-center -->';
				echo '</figure>';
			}
            elseif( 'style22' == $this->get_settings_for_display( 'style' ) ) {
                printf( '<figure>' );
                liquid_the_post_thumbnail( $size, array( 'class' => 'w-100' ), true );
                echo '</figure>';
            }
			else {
				printf( '<figure class="lqd-lp-img %s">', $figure_classnames );
				liquid_the_post_thumbnail( $size, $attr, true );
				echo '</figure>';
				
			}

		}
	
	}

	protected function entry_content( $class = '' ) {

		$style = $this->get_settings_for_display('style');
		
		if( empty( $class ) ) {
			$class = 'lqd-lp-excerpt w-80 mb-3';
		}

		if( !is_single() ) :

	?>
			<div class="<?php echo $class; ?>">
				<?php
					add_filter( 'excerpt_length', array( $this, 'excerpt_lengh' ), 999 );
					add_filter( 'excerpt_more', array( $this, 'excerpt_more' ) );
					add_filter( 'liquid_dinamic_css_output', array( $this, 'clean_excerpt' ) );
					the_excerpt();
					remove_filter( 'liquid_dinamic_css_output', array( $this, 'clean_excerpt' ) ); ?>
			</div><!-- /.latest-post-excerpt -->
		<?php else: ?>
			<div class="entry-content">
			<?php
				/* translators: %s: Name of current post */
				the_content( sprintf(
					__( 'Continue reading %s', 'landinghub-core' ),
					the_title( '<span class="screen-reader-text">', '</span>', false )
				) );

				wp_link_pages( array(
					'before'      => '<div class="page-links"><span class="page-links-title">' . __( 'Pages:', 'landinghub-core' ) . '</span>',
					'after'       => '</div>',
					'link_before' => '<span>',
					'link_after'  => '</span>',
					'pagelink'    => '<span class="screen-reader-text">' . __( 'Page', 'landinghub-core' ) . ' </span>%',
					'separator'   => '<span class="screen-reader-text">, </span>',
				) );
			?>
	    </div>
	<?php endif;

	}

	protected function entry_cats() {

		$categories_list = get_the_category_list( _x( ', ', 'Used between list items, there is a space after the comma.', 'landinghub-core' ) );

		if ( $categories_list ) {
			printf( '<span class="cat-links"><span class="screen-reader-text">%1$s </span>%2$s</span>',
				_x( 'Categories', 'Used before category names.', 'landinghub-core' ),
				$categories_list
			);
		}
	}

	protected function entry_time() {

		printf( '<time class="lqd-lp-date pos-rel z-index-2" datetime="%s">', get_the_date( 'c' ) );
		printf( _x( '%s ago', '%s = human-readable time difference', 'landing-hub' ), human_time_diff( get_the_time( 'U' ), current_time( 'timestamp' ) ) );
		echo '</time>';
		
		
	}

	protected function entry_time_to_read() {

		$time_to_read = liquid_helper()->get_option( 'post-time-read' );
		if( empty( $time_to_read ) ) {
			return;
		}

		printf( '<span class="post-time-read"><i class="fa fa-book"></i> %s</span>',
				esc_html( $time_to_read )
		);

	}

	public function excerpt_lengh( $length ) {

		$post_excerpt_length = $this->get_settings_for_display('post_excerpt_length');

		if( !isset( $post_excerpt_length ) ) {
			return '20';
		}
		return $post_excerpt_length;
	}

	public function excerpt_more( $more ) {

		$post_excerpt_length = $this->get_settings_for_display('post_excerpt_length');
		
		if( !isset( $post_excerpt_length ) ) {
			return $more;
		}
		return '';

	}
	
	public function clean_excerpt() {
		return false;
	}

	public function entry_read_more_button() {

		return $this->get_settings_for_display( 'show_read_more_button' );

	}

}
