<?php
namespace LiquidElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Utils;
use Elementor\Control_Media;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Repeater;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Elementor heading widget.
 *
 * Elementor widget that displays an eye-catching headlines.
 *
 * @since 1.0.0
 */
class LD_Content_Box extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve heading widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'ld_content_box';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve heading widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Liquid Box', 'elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve heading widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-info-box lqd-element';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the heading widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'hub-core' ];
	}

	/**
	 * Get widget keywords.
	 *
	 * Retrieve the list of keywords the widget belongs to.
	 *
	 * @since 2.1.0
	 * @access public
	 *
	 * @return array Widget keywords.
	 */
	public function get_keywords() {
		return [ 'box', 'image'  ];
	}

	/**
	 * Retrieve the list of scripts the counter widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return array( 'stackblur' );
	}

	/**
	 * Register heading widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

		// General Section
		$this->start_controls_section(
			'general_section',
			[
				'label' => __( 'General', 'hub-elementor-addons' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'template',
			[
				'label' => __( 'Style', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 's01',
				'options' => [
					's01' => __( 'Style 1', 'hub-elementor-addons' ),
					's01a' => __( 'Style 1 A', 'hub-elementor-addons' ),
					's01b' => __( 'Style 1 B', 'hub-elementor-addons' ),
					's02' => __( 'Style 2', 'hub-elementor-addons' ),
					's03' => __( 'Style 3', 'hub-elementor-addons' ),
					's04' => __( 'Style 4', 'hub-elementor-addons' ),
					's05' => __( 'Style 5', 'hub-elementor-addons' ),
					's06' => __( 'Style 6', 'hub-elementor-addons' ),
					's07' => __( 'Style 7', 'hub-elementor-addons' ),
					's08' => __( 'Style 8', 'hub-elementor-addons' ),
					's09' => __( 'Style 9', 'hub-elementor-addons' ),
					's10' => __( 'Style 10', 'hub-elementor-addons' ),
					's11' => __( 'Style 11', 'hub-elementor-addons' ),
				],
			]
		);

		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'hub-elementor-addons' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Title', 'hub-elementor-addons' ),
				'placeholder' => __( 'Type your title here', 'hub-elementor-addons' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'label' => __( 'Title Typography', 'hub-elementor-addons' ),
				'selector' => '{{WRAPPER}} .lqd-fb-content h2',
			]
		);

		$this->add_control(
			'subtitle',
			[
				'label' => __( 'Subtitle', 'hub-elementor-addons' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Subtitle', 'hub-elementor-addons' ),
				'placeholder' => __( 'Type your subtitle here', 'hub-elementor-addons' ),
				'condition' => [
					'template' => 's06'
				]
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'subtitle_typography',
				'label' => __( 'Subtitle Typography', 'hub-elementor-addons' ),
				'selector' => '{{WRAPPER}} h6',
				'condition' => [
					'template' => 's06'
				]
			]
		);

		$this->add_control(
			'content_alignment',
			[
				'label' => __( 'Content Alignment', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => __( 'Default', 'hub-elementor-addons' ),
					'lqd-fb-content-br' => __( 'Bottom Right', 'hub-elementor-addons' ),
					'lqd-fb-content-bc' => __( 'Bottom Center', 'hub-elementor-addons' ),
					'lqd-fb-content-mid' => __( 'Middle', 'hub-elementor-addons' ),
				],
				'condition' => [
					'template' => 's08'
				]
			]
		);

		$this->add_control(
			'ct_width',
			[
				'label' => __( 'Content Width', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'w-60',
				'options' => [
					'w-50' => __( '50%', 'hub-elementor-addons' ),
					'w-60' => __( '60%', 'hub-elementor-addons' ),
					'w-70' => __( '70%', 'hub-elementor-addons' ),
					'w-80' => __( '80%', 'hub-elementor-addons' ),
					'w-90' => __( '90%', 'hub-elementor-addons' ),
					'w-100' => __( '100%', 'hub-elementor-addons' ),
				],
				'condition' => [
					'template' => 's08'
				]
			]
		);

		$this->add_control(
			'ct_alignment',
			[
				'label' => __( 'Content Alignment', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'text-center',
				'options' => [
					'text-center' => __( 'Default', 'hub-elementor-addons' ),
					'text-left' => __( 'Left', 'hub-elementor-addons' ),
					'text-right' => __( 'Right', 'hub-elementor-addons' ),
				],
				'condition' => [
					'template' => 's09'
				]
			]
		);

		$this->add_control(
			'box_height',
			[
				'label' => __( 'Box Height', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'h-pt-50',
				'options' => [
					'h-pt-50' => __( '50%', 'hub-elementor-addons' ),
					'h-pt-60' => __( '60%', 'hub-elementor-addons' ),
					'h-pt-70' => __( '70%', 'hub-elementor-addons' ),
					'h-pt-80' => __( '80%', 'hub-elementor-addons' ),
					'h-pt-90' => __( '90%', 'hub-elementor-addons' ),
					'h-pt-100' => __( '100%', 'hub-elementor-addons' ),
					'h-custom' => __( 'Custom', 'hub-elementor-addons' ),
				],
				'condition' => [
					'template' => 's01'
				]
			]
		);

		$this->add_responsive_control(
			'box_height_custom',
			[
				'label' => __( 'Height', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'vw', 'vh' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 500,
						'step' => 1
					],
					'%' => [
						'min' => 0,
						'max' => 100,
						'step' => 1
					],
					'vw' => [
						'min' => 0,
						'max' => 100,
						'step' => 1
					],
					'vw' => [
						'min' => 0,
						'max' => 100,
						'step' => 1
					],
				],
				'condition' => [
					'box_height' => 'h-custom',
				],
				'selectors' => [
					'{{WRAPPER}} .lqd-fb' => 'height: {{SIZE}}{{UNIT}}; padding: 0 !important;',
				]
			]
		);

		$this->add_control(
			'box_height_a',
			[
				'label' => __( 'Box Height', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'h-pt-100',
				'options' => [
					'h-pt-50' => __( '50%', 'hub-elementor-addons' ),
					'h-pt-60' => __( '60%', 'hub-elementor-addons' ),
					'h-pt-70' => __( '70%', 'hub-elementor-addons' ),
					'h-pt-80' => __( '80%', 'hub-elementor-addons' ),
					'h-pt-100' => __( '100%', 'hub-elementor-addons' ),
					'h-custom' => __( 'Custom', 'hub-elementor-addons' ),
				],
				'condition' => [
					'template' => 's01a'
				]
			]
		);

		$this->add_responsive_control(
			'box_height_custom_a',
			[
				'label' => __( 'Height', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'vw', 'vh' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 500,
						'step' => 1
					],
					'%' => [
						'min' => 0,
						'max' => 100,
						'step' => 1
					],
					'vw' => [
						'min' => 0,
						'max' => 100,
						'step' => 1
					],
					'vw' => [
						'min' => 0,
						'max' => 100,
						'step' => 1
					],
				],
				'condition' => [
					'box_height_a' => 'h-custom',
				],
				'selectors' => [
					'{{WRAPPER}} .lqd-fb' => 'height: {{SIZE}}{{UNIT}}; padding: 0 !important;',
				]
			]
		);

		$this->add_control(
			'box_height_b',
			[
				'label' => __( 'Box Height', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'h-pt-80',
				'options' => [
					'h-pt-50' => __( '50%', 'hub-elementor-addons' ),
					'h-pt-60' => __( '60%', 'hub-elementor-addons' ),
					'h-pt-70' => __( '70%', 'hub-elementor-addons' ),
					'h-pt-80' => __( '80%', 'hub-elementor-addons' ),
					'h-pt-100' => __( '100%', 'hub-elementor-addons' ),
					'h-custom' => __( 'Custom', 'hub-elementor-addons' ),
				],
				'condition' => [
					'template' => 's01b'
				]
			]
		);

		$this->add_responsive_control(
			'box_height_custom_b',
			[
				'label' => __( 'Height', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'vw', 'vh' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 500,
						'step' => 1
					],
					'%' => [
						'min' => 0,
						'max' => 100,
						'step' => 1
					],
					'vw' => [
						'min' => 0,
						'max' => 100,
						'step' => 1
					],
					'vw' => [
						'min' => 0,
						'max' => 100,
						'step' => 1
					],
				],
				'condition' => [
					'box_height_b' => 'h-custom',
				],
				'selectors' => [
					'{{WRAPPER}} .lqd-fb' => 'height: {{SIZE}}{{UNIT}}; padding: 0 !important;',
				]
			]
		);

		$this->add_control(
			'box_height_6',
			[
				'label' => __( 'Box Height', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'h-pt-125',
				'options' => [
					'h-pt-50' => __( '50%', 'hub-elementor-addons' ),
					'h-pt-60' => __( '60%', 'hub-elementor-addons' ),
					'h-pt-70' => __( '70%', 'hub-elementor-addons' ),
					'h-pt-80' => __( '80%', 'hub-elementor-addons' ),
					'h-pt-90' => __( '90%', 'hub-elementor-addons' ),
					'h-pt-100' => __( '100%', 'hub-elementor-addons' ),
					'h-pt-125' => __( '125%', 'hub-elementor-addons' ),
					'h-custom' => __( 'Custom', 'hub-elementor-addons' ),
				],
				'condition' => [
					'template' => 's06'
				]
			]
		);

		$this->add_responsive_control(
			'box_height_custom_6',
			[
				'label' => __( 'Height', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'vw', 'vh' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 500,
						'step' => 1
					],
					'%' => [
						'min' => 0,
						'max' => 100,
						'step' => 1
					],
					'vw' => [
						'min' => 0,
						'max' => 100,
						'step' => 1
					],
					'vw' => [
						'min' => 0,
						'max' => 100,
						'step' => 1
					],
				],
				'condition' => [
					'box_height_6' => 'h-custom',
				],
				'selectors' => [
					'{{WRAPPER}} .lqd-fb' => 'height: {{SIZE}}{{UNIT}}; padding: 0 !important;',
				]
			]
		);

		$this->add_control(
			'label',
			[
				'label' => __( 'Label', 'hub-elementor-addons' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Label', 'hub-elementor-addons' ),
				'placeholder' => __( 'Type your label here', 'hub-elementor-addons' ),
				'condition' => [
					'template' => [
						's01', 's01b', 's03'
					]
				]
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'label_typography',
				'label' => __( 'Label Typography', 'hub-elementor-addons' ),
				'selector' => '{{WRAPPER}} .lqd-fb-content h6',
				'condition' => [
					'template' => [
						's01', 's01b', 's03'
					]
				]
			]
		);

		$this->add_responsive_control(
			'label_padding',
			[
				'label' => __( 'Label Padding', 'hub-elementor-addons' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .lqd-fb-content h6' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'condition' => array(
					'template' => [
						's01', 's01b', 's03'
					]
				),
			]
		);

		$this->add_control(
			'image',
			[
				'label' => __( 'Image', 'hub-elementor-addons' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					//'template!' => ['s10']
				],
			]
		);

		
		$this->add_control(
			'img_link',
			[
				'label' => __( 'Link', 'hub-elementor-addons' ),
				'type' => Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'hub-elementor-addons' ),
			]
		);

		$this->add_control(
			'content2',
			[
				'label' => __( 'Text', 'hub-elementor-addons' ),
				'type' => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Type your text here', 'hub-elementor-addons' ),
				'condition' => [
					'template' => [
						's01', 's01a', 's01b', 's02', 's04', 's05', 's06', 's10' 
					]
				]
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'content_typography',
				'label' => __( 'Content Typography', 'hub-elementor-addons' ),
				'selector' => '{{WRAPPER}} p',
				'condition' => [
					'template' => [
						's01', 's01a', 's01b', 's02', 's04', 's05', 's06', 's10' 
					]
				]
			]
		);

		$this->add_control(
			'i_type',
			[
				'label' => __( 'Icon Library', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'fontawesome',
				'options' => [
					'fontawesome'  => __( 'Icon Library', 'hub-elementor-addons' ),
					//'image' => __( 'Image', 'hub-elementor-addons' ),
				],
				'condition' => [
					'template' => [ 's06', 's08' ],
				],
			]
		);

		$this->add_control(
			'i_icon_fontawesome',
			[
				'label' => __( 'Icon', 'hub-elementor-addons' ),
				'type' => Controls_Manager::ICONS,
				'default' => [
					'value' => 'fa fa-star',
					'library' => 'solid',
				],
				'condition' => [
					'template' => [ 's06', 's08' ],
				],
			]
		);
		$this->end_controls_section();
		
		// Style Tab
		$this->start_controls_section(
			'style_section',
			[
				'label' => __( 'Style Section', 'hub-elementor-addons' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'overlay_color_heading',
			[
				'label' => __( 'Overlay Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'overlay_color',
				'label' => __( 'Hover Image Overlay Color', 'hub-elementor-addons' ),
				'types' => [ 'classic', 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '{{WRAPPER}} .lqd-fb-bg',
				'fields_options' => [
					'background' => [
						'default' => 'classic',
					],
				],
				'condition' => [
					'template!' => [
						's04', 's05', 's07', 's08', 's10'
					]
				],
			]
		);

		
		$this->add_control(
			'overlay_hcolor_heading',
			[
				'label' => __( 'Hover Image Overlay Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'overlay_hcolor',
				'label' => __( 'Hover Image Overlay Color', 'hub-elementor-addons' ),
				'types' => [ 'classic', 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '{{WRAPPER}} .lqd-fb-hover-overlay',
				'fields_options' => [
					'background' => [
						'default' => 'classic',
					],
				],
				'condition' => [
					'template!' => [
						's08', 's10'
					]
				],
			]
		);

		$this->add_control(
			'content_bg',
			[
				'label' => __( 'Content Background', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-fb-content' => 'background: {{VALUE}}',
				],
				'condition' => [
					'template!' => [
						's10'
					]
				],
				'separator' => 'before',
			]
		);

		$this->add_control(
			'revealer_color',
			[
				'label' => __( 'Revealer Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .block-revealer__element' => 'background: {{VALUE}}',
				],
				'condition' => [
					'template!' => [
						's02', 's03', 's08'
					]
				]
			]
		);

		$this->add_control(
			'hover_revealer_color',
			[
				'label' => __( 'Hover Revealer Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .block-revealer__element:before' => 'background: {{VALUE}}',
				],
				'condition' => [
					'template' => [
						's08'
					]
				]
			]
		);

		$this->add_control(
			'heading_color',
			[
				'label' => __( 'Heading Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-fb-content h2' => 'color: {{VALUE}}',
					'{{WRAPPER}} .lqd-fb-title i' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'heading_hcolor',
			[
				'label' => __( 'Heading Hover Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-fb:hover .lqd-fb-content h2' => 'color: {{VALUE}}',
					'{{WRAPPER}} .lqd-fb:hover .lqd-fb-title i' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'content_color',
			[
				'label' => __( 'Content Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-fb-content p' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'subtitle_color',
			[
				'label' => __( 'Subtitle Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-fb-style-6 h6' => 'color: {{VALUE}}',
				],
				'condition' => [
					'template' => [
						's06'
					]
				]
			]
		);

		$this->add_control(
			'hover_text_color',
			[
				'label' => __( 'Hover Text Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-fb-content' => 'color: {{VALUE}}',
				],
				'condition' => [
					'template' => [
						's08'
					]
				]
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'label_bg',
				'label' => __( 'Hover Image Overlay Color', 'hub-elementor-addons' ),
				'types' => [ 'classic', 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '{{WRAPPER}} .lqd-fb-content h6',
				'fields_options' => [
					'background' => [
						'default' => 'classic',
					],
				],
				'condition' => [
					'template' => [
						's01', 's01b', 's03'
					]
				],
				'separator' => 'before'
			]
		);

		$this->add_control(
			'label_color',
			[
				'label' => __( 'Label Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-fb-content h6' => 'color: {{VALUE}}',
				],
				'condition' => [
					'template' => [
						's01', 's01b', 's03'
					]
				]
			]
		);

		$this->end_controls_section();

		ld_el_btn($this, 'ib_', $condition = ['template' => ['s01', 's01a', 's01b', 's02', 's04', 's05', 's06', 's10']]); // load button
	}

	// Button Functions 
	protected function get_button() {
		
		extract( $this->get_settings_for_display() );
		$ib_link = isset($ib_link['url']) ? $ib_link['url'] : '';
		$ib_i_icon = isset($ib_icon['value']) ? $ib_icon['value'] : '';

		$ib_classes = array( 
			'elementor-button',
			'btn',
			$ib_style,
			$ib_i_separator,
			$ib_hover_txt_effect,
			$ib_size,
			$ib_border_w,
			$this->get_width(),
		
			($ib_link_type === 'lightbox') ? 'fresco' : '',
			
			//Icon Classes
			$ib_i_position,
			$ib_i_shape_size,
			$ib_i_shape,
			$ib_i_shape_style,	
			$ib_i_shape_bw,	
			$ib_i_ripple,
			$ib_i_hover_reveal,
			!empty( $ib_title ) ? 'btn-has-label' : 'btn-no-label',
		);

	 if ($show_button === 'yes'){

		$ib_attributes['href'] = trim($ib_link);
		$ib_attributes['class'] = ld_helper()->sanitize_html_classes( $ib_classes );

		if( !empty( $ib_image_caption ) ) {
			$ib_attributes['data-fresco-caption'] = $ib_image_caption;
		} 

		if( 'modal_window' === $ib_link_type ) {
			$ib_attributes['data-lity'] = isset( $ib_anchor_id ) ? esc_url( $ib_anchor_id ) : '#modal-box';
			$ib_attributes['href'] = isset( $ib_anchor_id ) ? esc_url( $ib_anchor_id ) : '#modal-box';
		}
		elseif( 'local_scroll' === $ib_link_type ) {
			$ib_attributes['data-localscroll'] = true;
			$ib_attributes['href'] = isset( $ib_anchor_id ) ? esc_url( $ib_anchor_id ) : '#';
			if( !empty( $ib_scroll_speed ) ) {
				$ib_attributes['data-localscroll-options'] = wp_json_encode( array( 'scrollSpeed' => $ib_scroll_speed ) );	
			}
			
		}
		elseif( 'scroll_to_section' === $ib_link_type ) {
			$ib_attributes['data-localscroll'] = true;
			if( !empty( $ib_scroll_speed ) ) {
				$ib_attributes['data-localscroll-options'] = wp_json_encode( array( 'scrollBelowSection' => true, 'scrollSpeed' => $ib_scroll_speed ) );	
			}
			else {
				$ib_attributes['data-localscroll-options'] = wp_json_encode( array( 'scrollBelowSection' => true ) );	
			}
			
			$ib_attributes['href'] = '#';
		}?>
		<a <?php echo ld_helper()->html_attributes( $ib_attributes ) ?> >
			<?php if( !empty( $ib_title ) ) { ?>
				<span class="btn-txt" data-text="<?php echo esc_attr( $ib_title ) ?>" <?php $this->get_hover_text_opts(); ?>><?php echo wp_kses_post( do_shortcode( $ib_title ) ); ?></span>
			<?php } ?>
			<?php
				if( $ib_i_icon ) {
					printf( '<span class="btn-icon"><i class="%s"></i></span>', $ib_i_icon );
				}
				if( 'btn-hover-swp' === $ib_i_hover_reveal ) {
					printf( '<span class="btn-icon"><i class="%s"></i></span>', $ib_i_icon );
				}
			?>
		</a>
		<?php

		}
	}
	
	protected function get_border() {

		$style = $this->get_settings_for_display('ib_style');
		
		if( 'btn-naked' == $style || 'btn-underlined' == $style ) {
			return;
		}

		$border = $this->get_settings_for_display('ib_border');

		if ( 'btn-solid' == $style) {
			return $border;	
		}
		
		return "btn-bordered $border";	
	}

	protected function get_width() {
		
		$style = $this->get_settings_for_display('ib_style');

		if( 'btn-naked' === $style || 'btn-underlined' === $style ) {
			return;
		}

		$width = $this->get_settings_for_display('ib_width');
		
		return "$width";	
	}

	protected function get_hover_text_opts() {

		$effect = $this->get_settings_for_display('ib_hover_txt_effect');
		if( empty( $effect ) ) {
			return;
		}

		$start_delay = 0;
		$out = '';
		
		switch( $effect ) {
			
			case 'btn-hover-txt-liquid-x':
			default:
				
				$out = 'data-transition-delay="true"
					    data-delay-options=\'{"elements": ".lqd-chars", "delayType": "animation", "startDelay": ' . $start_delay . ', "delayBetween": 32.5}\'
					    data-split-text="true"
					    data-split-options=\'{"type": "chars, words"}\'';
			break;
			
			case 'btn-hover-txt-liquid-x-alt':
				
				$out = 'data-transition-delay="true"
					    data-delay-options=\'{"elements": ".lqd-chars", "delayType": "animation", "startDelay": ' . $start_delay . ', "delayBetween": 32.5, "reverse": true}\'
					    data-split-text="true"
					    data-split-options=\'{"type": "chars, words"}\'';

			break;
			
			case 'btn-hover-txt-liquid-y':
				
				$out = 'data-transition-delay="true"
					    data-delay-options=\'{"elements": ".lqd-chars", "delayType": "animation", "startDelay": ' . $start_delay . ', "delayBetween": 32.5}\'
					    data-split-text="true"
					    data-split-options=\'{"type": "chars, words"}\'';
			break;

			case 'btn-hover-txt-liquid-y-alt':
				
				$out = 'data-transition-delay="true"
				        data-delay-options=\'{"elements": ".lqd-chars", "delayType": "animation", "startDelay": ' . $start_delay . ', "delayBetween": 32.5}\'
				        data-split-text="true"
				        data-split-options=\'{"type": "chars, words"}\'';
			break;

		}

		echo $out;

	}	

	/**
	 * Render heading widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		
		$settings = $this->get_settings_for_display();

		$classes = array(
			'lqd-fb',
			'pos-rel',
		);
		$wrapper_attr = array();

		
		switch($settings['template']){
			case 's01':
				array_push($classes, 'lqd-fb-style-1', $settings['box_height'], 'overflow-hidden', 'lqd-fb-zoom-img-onhover', 'round');
				$wrapper_attr['data-inview'] = 'true';
			break;
			case 's01a':
				array_push($classes, 'lqd-fb-style-1', 'lqd-fb-style-1-2', $settings['box_height_a'], 'lqd-fb-zoom-img-onhover', 'overflow-hidden', 'round');
				$wrapper_attr['data-inview'] = 'true';
			break;
			case 's01b':
				array_push($classes, 'lqd-fb-style-1', 'lqd-fb-style-1-3', $settings['box_height_b'], 'lqd-fb-zoom-img-onhover', 'overflow-hidden', 'round');
				$wrapper_attr['data-inview'] = 'true';
			break;
			case 's02':
				array_push($classes, 'lqd-fb-style-2');
			break;
			case 's03':
				array_push($classes, 'lqd-fb-style-3', 'lqd-fb-zoom-img-onhover');
			break;
			case 's04':
				array_push($classes, 'lqd-fb-style-4', 'lqd-fb-zoom-img-onhover');
			break;
			case 's05':
				array_push($classes, 'lqd-fb-style-5', 'overflow-hidden');
			break;
			case 's06':
				array_push($classes, 'round', 'lqd-fb-style-6', $settings['box_height_6']);
				$wrapper_attr['data-lqd-zindex'] = 'true';
			break;
			case 's07':
				array_push($classes, 'lqd-fb-style-7', 'overflow-hidden', 'round');
			break;
			case 's08':
				array_push($classes, 'lqd-fb-style-8' , $settings['content_alignment'] );
			break;
			case 's09':
				array_push($classes, 'lqd-fb-style-9', $settings['ct_alignment'], 'text-center', 'overflow-hidden', 'border-radius-10');
			break;
			case 's10':
				array_push($classes, 'lqd-fb-style-10');
			break;
			case 's11':
				array_push($classes, 'lqd-fb-style-11 text-center');
			break;
		}
		
		?> 

		<div class="<?php echo ld_helper()->sanitize_html_classes( $classes ); ?>" <?php echo ld_helper()->html_attributes( $wrapper_attr ) ?> >
		<?php
		
		switch($settings['template']){
			case 's01':
			?>

			<div class="lqd-fb-inner lqd-overlay" data-slideelement-onhover="true" data-slideelement-options='{ "visibleElement": "h6, h2", "hiddenElement": ".lqd-fb-txt" }'>

				<div class="lqd-fb-img lqd-overlay overflow-hidden">

				<figure class="w-100 d-flex">
					<?php echo '<img class="h-100 objfit-cover objpos-center flex-grow" src="' . esc_url($settings['image']['url']) . '">'; ?>
				</figure>

				</div>

				<div class="lqd-fb-content lqd-overlay align-items-end">
					<div class="lqd-fb-bg lqd-overlay"></div>
					<div
					class="lqd-fb-content-inner pos-rel p-4 p-md-7 w-100"
					data-custom-animations="true"
					data-ca-options='{ "triggerHandler": "inview", "animationTarget": "all-childs", "duration": 1200, "delay": 120,  "startDelay": 250, "initValues": { "y": 30, "opacity": 0 }, "animations": { "y": 0, "opacity": 1 } }'>
						
						<?php if( !empty( $settings['label'] ) ) { ?>
						<h6 class="my-0 mb-4">
							<?php echo $settings['label']; ?>
						</h6>
						<?php } ?>
						
						<?php if( !empty( $settings['title'] ) ) { ?>
						<h2
						class="my-0"
						data-split-text="true" data-split-options='{ "type": "lines" }'>
							<?php echo $settings['title']; ?>
						</h2>
						<?php } ?>
						
						<?php if( !empty( $settings['content2'] ) || 'yes' === $settings['show_button'] ) { ?>
							<div class="lqd-fb-txt">
							<?php if( !empty( $settings['content2'] ) ) { ?>
								<p class="my-0 mb-3"><?php echo $settings['content2']; ?></p>
							<?php } ?>
							<?php if( 'yes' === $settings['show_button'] ) { ?>
								<?php $this->get_button() ?>
							<?php } ?>
							</div>
						<?php } ?>

						<?php if( $settings['img_link']['url'] ): ?>
							<a href="<?php echo esc_url($settings['img_link']['url']); ?>" class="liquid-overlay-link"></a>
						<?php endif; ?>
						
					</div>
				</div>

			</div>

			<?php
			break;
			case 's01a':
			?>
			<div class="lqd-fb-inner lqd-overlay">

				<div class="lqd-fb-img lqd-overlay overflow-hidden">

					<figure class="w-100 d-flex">
						<?php echo '<img class="h-100 objfit-cover objpos-center flex-grow" src="' . esc_url($settings['image']['url']) . '">'; ?>
					</figure>

				</div>

				<div class="lqd-fb-content lqd-overlay align-items-end">
					<div class="lqd-fb-bg lqd-overlay"></div>
					<div class="lqd-fb-hover-overlay lqd-overlay"></div>
					<div class="lqd-fb-content-inner d-flex flex-wrap align-items-center pos-rel px-2 py-5 w-100">
						<?php if( 'yes' === $settings['show_button'] ) { ?>
						<div
						class="w-20 px-2 text-center"
						data-custom-animations="true"
						data-ca-options='{ "triggerHandler": "inview", "animationTarget": "all-childs", "duration": 1000, "delay": 120,  "startDelay": 250, "initValues": { "scale": 1.2, "opacity": 0 }, "animations": { "scale": 1, "opacity": 1 } }'>
						<?php $this->get_button() ?>
						</div>
						<?php } ?>
						
						<?php if( !empty( $settings['title'] ) ) { ?>
						<div
						class="w-80 px-2"
						data-custom-animations="true"
						data-ca-options='{ "triggerHandler": "inview", "animationTarget": "all-childs", "duration": 1000, "delay": 120,  "startDelay": 250, "initValues": { "y": 20, "opacity": 0 }, "animations": { "y": 0, "opacity": 1 } }'>
							<h3
							class="my-0"
							data-split-text="true" data-split-options='{ "type": "lines" }'><?php echo $settings['title']; ?></h3>
						</div>
						<?php } ?>

						<?php if( $settings['img_link']['url'] ): ?>
							<a href="<?php echo esc_url($settings['img_link']['url']); ?>" class="liquid-overlay-link"></a>
						<?php endif; ?>

					</div>
				</div>

			</div>
			<?php
			break;
			case 's01b':
			?>
			<div class="lqd-fb-inner lqd-overlay">

				<div class="lqd-fb-img lqd-overlay overflow-hidden">

					<figure class="w-100 d-flex">
						<?php echo '<img class="h-100 objfit-cover objpos-center flex-grow" src="' . esc_url($settings['image']['url']) . '">'; ?>
					</figure>

				</div>

				<div class="lqd-fb-content lqd-overlay align-items-end">
					<div class="lqd-fb-bg lqd-overlay"></div>
					<div class="lqd-fb-hover-overlay lqd-overlay"></div>
					<div class="lqd-fb-content-inner d-flex flex-column justify-content-end pos-rel h-100 w-100 p-4 p-md-5">
						
						<?php if( !empty( $settings['label'] ) ) { ?>
						<div class="lqd-fb-content-top">
							<h6 class="my-0 text-uppercase ltr-sp-25"><?php echo $settings['label']; ?></h6>
						</div>
						<?php } ?>
						
						<div class="lqd-fb-content-bottom mt-auto">
							
							<?php if( !empty( $settings['title'] ) ) { ?>
							<h2 class="my-0 mb-2"><?php echo $settings['title']; ?></h2>
							<?php } ?>
							
							
							<?php if( !empty( $settings['content2'] ) ) { ?>
							<p class="my-0 mb-3"><?php echo $settings['content2']; ?></p>
							<?php } ?>

							<?php $this->get_button() ?>

						</div>

						<?php if( $settings['img_link']['url'] ): ?>
							<a href="<?php echo esc_url($settings['img_link']['url']); ?>" class="liquid-overlay-link"></a>
						<?php endif; ?>
						
					</div>
				</div>

				</div>
			<?php
			break;
			case 's02':
			?>
			<div class="lqd-fb-inner lqd-overlay">

				<div class="lqd-fb-img lqd-overlay overflow-hidden">
			
					<figure class="w-100 d-flex">
						<?php echo '<img class="h-100 objfit-cover objpos-center flex-grow" src="' . esc_url($settings['image']['url']) . '">'; ?>
					</figure>
						
					<?php if( $settings['img_link']['url'] ): ?>
						<a href="<?php echo esc_url($settings['img_link']['url']); ?>" class="liquid-overlay-link"></a>
					<?php endif; ?>

				</div>

				<div class="lqd-fb-content lqd-overlay align-items-end">
					<div class="lqd-fb-content-inner d-flex flex-wrap align-items-center pos-rel px-3 px-md-7 py-4 py-md-6 w-100">
						<div class="lqd-overlay" data-reveal="true" data-reveal-options='{ "direction": "bt", "bgcolor": "#000", "delay": 150, "duration": 500 }'>
							<div class="lqd-fb-bg lqd-overlay"></div>
							<div class="lqd-fb-hover-overlay lqd-overlay"></div>
						</div>

						<?php if( !empty( $settings['title'] ) ) { ?>
						<div
						class="w-65 pos-rel"
						data-custom-animations="true"
						data-ca-options='{ "triggerHandler": "inview", "animationTarget": "all-childs", "duration": 1200, "delay": 120,  "startDelay": 800, "initValues": { "y": 30, "opacity": 0 }, "animations": { "y": 0, "opacity": 1 } }'>
							<h2
							class="my-0"
							data-split-text="true" data-split-options='{ "type": "lines" }'><?php echo $settings['title']; ?></h2>
						</div>
						<?php } ?>
						
						<div
						class="w-35 pos-rel text-md-right"
						data-custom-animations="true"
						data-ca-options='{ "triggerHandler": "inview", "animationTarget": "all-childs", "duration": 1200, "delay": 120,  "startDelay": 950, "initValues": { "y": 30, "opacity": 0 }, "animations": { "y": 0, "opacity": 1 } }'>
						<?php $this->get_button() ?>
						</div>
					</div>
				</div>

				</div>
			<?php
			break;
			case 's03':
			?>

			<div class="lqd-fb-inner" data-reveal="true" data-reveal-options='{ "direction": "bt", "bgcolor": "#000", "duration": 500 }'>

				<div class="lqd-fb-img overflow-hidden">
				
					<figure class="w-100 d-flex">
						<?php echo '<img class="h-100 objfit-cover objpos-center flex-grow" src="' . esc_url($settings['image']['url']) . '">'; ?>
					</figure>
						
					<?php if( $settings['img_link']['url'] ): ?>
						<a href="<?php echo esc_url($settings['img_link']['url']); ?>" class="liquid-overlay-link"></a>
					<?php endif; ?>

				</div>

				<div class="lqd-fb-content pos-rel">
					<div class="lqd-fb-bg lqd-overlay"></div>
					<div class="lqd-fb-hover-overlay lqd-overlay"></div>
					<div
					class="lqd-fb-content-inner d-flex flex-column pos-rel px-6 py-4"
					data-custom-animations="true"
					data-ca-options='{ "triggerHandler": "inview", "animationTarget": "all-childs", "duration": 1200, "delay": 120,  "startDelay": 500, "initValues": { "y": 30, "opacity": 0 }, "animations": { "y": 0, "opacity": 1 } }'>
						<?php if( !empty( $settings['title'] ) ) { ?>
						<h2
						class="my-0 mb-2"
						data-split-text="true" data-split-options='{ "type": "lines" }'><?php echo $settings['title']; ?></h2>
						<?php } ?>
						
						<?php if( !empty( $settings['label'] ) ) { ?>
						<h6
						class="my-0"
						data-split-text="true" data-split-options='{ "type": "lines" }'><?php echo $settings['label']; ?></h6>
						<?php } ?>
					</div>
				</div>

			</div>

			<?php
			break;
			case 's04':
			?>
			<div class="lqd-fb-inner">

				<div class="lqd-fb-img overflow-hidden">
					
					<figure class="w-100 d-flex">
						<?php echo '<img class="h-100 objfit-cover objpos-center flex-grow" src="' . esc_url($settings['image']['url']) . '">'; ?>
					</figure>
						
					<?php if( $settings['img_link']['url'] ): ?>
						<a href="<?php echo esc_url($settings['img_link']['url']); ?>" class="liquid-overlay-link"></a>
					<?php endif; ?>

				</div>

				<div class="lqd-fb-content pos-rel">
					<div class="lqd-fb-bg lqd-overlay"></div>
					<div class="lqd-fb-hover-overlay lqd-overlay"></div>
					<div class="lqd-fb-content-inner pos-rel text-center p-5">

						<?php if( !empty( $settings['title'] ) ) { ?>
						<h2 class="my-0 mb-3 font-weight-normal"><?php echo $settings['title']; ?></h2>
						<?php } ?>
						
						<?php if( !empty( $settings['content2'] ) ) { ?>
						<p class="my-0"> <?php echo $settings['content2']; ?></p>
						<?php } ?>

					</div>
					
					
					<?php if( 'yes' === $settings['show_button'] ) { ?>
					<div class="lqd-fb-footer text-center py-3 px-5">
						<?php $this->get_button() ?>
					</div>
					<?php } ?>
					
				</div>

			</div>
			<?php
			break;
			case 's05':
			?>
			<div class="lqd-fb-inner d-flex flex-wrap align-items-center">

				<div class="w-25">
					<div class="lqd-fb-img">
						<figure class="circle overflo-hidden">

							<?php echo '<img class="h-100 objfit-cover objpos-center circle" src="' . esc_url($settings['image']['url']) . '">'; ?>
							
							<?php if( $settings['img_link']['url'] ): ?>
								<a href="<?php echo esc_url($settings['image']['url']); ?>" class="liquid-overlay-link"></a>
							<?php endif; ?>

						</figure>
					</div>
				</div>

				<div class="w-75">
					<div class="lqd-fb-content pos-rel">
						<div class="lqd-fb-bg lqd-overlay"></div>
						<div class="lqd-fb-hover-overlay lqd-overlay"></div>
						<div class="lqd-fb-content-inner pos-rel py-6 px-4">
							
							<?php if( !empty( $settings['title'] ) ) { ?>
							<h2 class="my-0 mb-3 font-weight-bold"><?php echo $settings['title']; ?></h2>
							<?php } ?>
							
							<?php if( !empty( $settings['content2'] ) ) { ?>
							<p class="my-0 mb-3"><?php echo $settings['content2']; ?></p>
							<?php } ?>
							
							<?php $this->get_button() ?>
						</div>
					</div>
				</div>

			</div>
			<?php
			break;
			case 's06':
			?>
				
			<div class="lqd-fb-shadow"></div>

			<div class="d-flex flex-wrap align-items-center lqd-overlay" data-hover3d="true">

				<div class="lqd-fb-content-wrap lqd-overlay flex-column align-items-end transform-style-3d backface-hidden will-change-transform" data-stacking-factor="0.5">

					<div class="lqd-fb-img lqd-overlay round backface-hidden">

						<figure class="d-flex w-100 h-100 bg-cover bg-center" style="background-image: url('<?php echo esc_url($settings['image']['url']) ?>')">
							<?php echo '<img class="hidden" src="' . esc_url($settings['image']['url']) . '">'; ?>
						</figure>

						<div class="lqd-fb-bg lqd-overlay"></div>
						<div class="lqd-fb-hover-overlay lqd-overlay"></div>
					</div>

					<div class="lqd-fb-content pos-abs pos-bl w-100 p-4 py-lg-7 px-lg-8 backface-hidden">

						<span class="lqd-fb-icon d-flex mb-5">
							<?php \Elementor\Icons_Manager::render_icon( $settings['i_icon_fontawesome'], [ 'aria-hidden' => 'true' ] ); ?>
						</span>

						<?php if( !empty( $settings['subtitle'] ) ) { ?>
						<h6 class="my-0 mb-3 font-weight-bold text-uppercase ltr-sp-2"><?php echo $settings['subtitle']; ?></h6>
						<?php } ?>
						
						<?php if( !empty( $settings['title'] ) ) { ?>
						<h2 class="my-0 mb-3 font-weight-bold"><?php echo $settings['title']; ?></h2>
						<?php } ?>
						
						<?php $this->get_button() ?>

					</div>

					<?php if( $settings['img_link']['url'] ): ?>
						<a href="<?php echo esc_url( $settings['img_link']['url'] ); ?>" class="liquid-overlay-link"></a>
					<?php endif; ?>

				</div>

			</div>
		
			<?php
			break;
			case 's07':
			?>
			<div class="lqd-fb-inner d-flex flex-wrap align-items-stretch">

				<div class="w-45 d-flex align-items-stretch">
					<div class="lqd-fb-img d-flex align-items-stretch w-100">
						<figure class="w-100 pos-rel">
							<?php echo '<img class="h-100 objfit-cover objpos-center pos-abs" src="' . esc_url($settings['image']['url']) . '">'; ?>
							
							<?php if( $settings['img_link']['url'] ): ?>
								<a href="<?php echo esc_url( $settings['img_link']['url'] ); ?>" class="liquid-overlay-link"></a>
							<?php endif; ?>

						</figure>
					</div>
				</div>

				<div class="w-55">
					<div class="lqd-fb-content pos-rel">
						<div class="lqd-fb-bg lqd-overlay"></div>
						<div class="lqd-fb-hover-overlay lqd-overlay"></div>
						<div class="lqd-fb-content-inner pos-rel py-6 px-5">
							
							<?php if( !empty( $settings['title'] ) ) { ?>
							<h2 class="my-0 mb-3 font-weight-semibold"><?php echo $settings['title']; ?></h2>
							<?php } ?>
							
							<?php if( !empty( $settings['content2'] ) ) { ?>
							<p class="my-0 mb-3"><?php echo $settings['content2']; ?></p>
							<?php } ?>

						</div>
					</div>
				</div>

			</div>

			<?php
			break;
			case 's08':
			?>
			<div class="lqd-fb-inner">

				<div
				class="lqd-fb-img round"
				data-custom-animations="true"
				data-ca-options='{ "triggerHandler": "inview", "animationTarget": "figure", "duration": 1200, "initValues": { "scale": 1.075, "opacity": 0 }, "animations": { "scale": 1, "opacity": 1 } }'>
					<figure>

							<?php echo '<img class="h-100 objfit-cover objpos-center flex-grow" src="' . esc_url($settings['image']['url']) . '">'; ?>
							
							<?php if( $settings['img_link']['url'] ): ?>
								<a href="<?php echo esc_url( $settings['img_link']['url'] ); ?>" class="liquid-overlay-link"></a>
							<?php endif; ?>

					</figure>
				</div>

				<div class="lqd-fb-content z-index-2 round <?php echo $settings['ct_width']; ?>">
					<div class="lqd-fb-content-inner d-flex flex-wrap align-items-center pos-rel round px-5 py-4">
						<div class="lqd-overlay" data-reveal="true" data-reveal-options='{ "direction": "bt", "delay": 150, "duration": 500, "coverArea": 100 }'>
							<div class="lqd-fb-bg lqd-overlay"></div>
						</div>
						<?php if( !empty( $settings['title'] ) ) { ?>
						<div
						class="w-80 pr-md-2 pos-rel"
						data-custom-animations="true"
						data-ca-options='{ "triggerHandler": "inview", "animationTarget": "all-childs", "duration": 1200, "delay": 120,  "startDelay": 800, "initValues": { "y": 30, "opacity": 0 }, "animations": { "y": 0, "opacity": 1 } }'>
							<h2 class="my-0" data-split-text="true" data-split-options='{ "type": "lines" }'><?php echo $settings['title']; ?></h2>
						</div>
						<?php } ?>
						<div
						class="w-20 pos-rel"
						data-custom-animations="true"
						data-ca-options='{ "triggerHandler": "inview", "animationTarget": "all-childs", "duration": 1100, "delay": 120,  "startDelay": 950, "initValues": { "y": 30, "opacity": 0 }, "animations": { "y": 0, "opacity": 1 } }'>
							<a class="lh-1 d-flex align-items-center justify-content-end lqd-fb-icon"<?php echo ld_helper()->html_attributes( $settings['img_link'] ) ?>>
								<?php $this->get_icon();?>
							</a>
						</div>
					</div>
				
					<a href="<?php echo esc_url( $settings['img_link']['url'] ); ?>" class="liquid-overlay-link"><?php echo $settings['title']; ?></a>
				</div>

				<a href="<?php echo esc_url( $settings['img_link']['url'] ); ?>" class="liquid-overlay-link"><?php echo $settings['title']; ?></a>

			</div>
			<?php
			break;
			case 's09':
			?>
			<div class="lqd-fb-inner">

				<div
				class="lqd-fb-img overflow-hidden"
				data-custom-animations="true"
				data-ca-options='{ "triggerHandler": "inview", "animationTarget": "figure", "duration": 1200, "initValues": { "scale": 1.15, "opacity": 0 }, "animations": { "scale": 1, "opacity": 1 } }'>
					<figure>
						<?php echo '<img src="' . esc_url($settings['image']['url']) . '">'; ?>
					</figure>
				</div>

				<div class="lqd-fb-content pos-rel px-3 py-4 d-flex flex-column">
					<div class="lqd-fb-content-inner pos-rel">
						<?php if( !empty( $settings['title'] ) ) { ?>
						<h2 class="mt-0 h4"><?php echo $settings['title']; ?></h2>
						<?php } ?>
						<?php if( !empty( $settings['content2'] ) ) { ?>
						<p><?php echo $settings['conten2']; ?></p>
						<?php } ?>
					</div>
				</div>

				<a href="<?php echo esc_url($settings['img_link']['url']); ?>" class="liquid-overlay-link"><?php echo $settings['title']; ?></a>

			</div>
			<?php
			break;
			case 's10':
			?>
			<div class="lqd-fb-inner">

				<div class="lqd-fb-content">
					<div class="lqd-fb-content-inner">
						
						<?php if( !empty( $settings['title'] ) ) { ?>
						<div class="lqd-fb-title pos-rel d-inline-flex mb-2">
							<h2 class="my-0"><?php echo $settings['title']; ?></h2>
							<i class="lqd-icn-ess icon-ion-ios-arrow-forward"></i>
						</div>
						<?php } ?>
						
						<?php if( !empty( $settings['content2'] ) ) { ?>
						<p class="my-0 mb-3"><?php echo $settings['content2']; ?></p>
						<?php } ?>
						
						<?php $this->get_button() ?>
					</div>
				</div>

			</div>
			<?php
			break;
			case 's11':
				?>
				<div class="lqd-fb-inner">

					<div class="lqd-fb-img">
						<figure>
							<?php echo '<img src="' . esc_url($settings['image']['url']) . '">'; ?>
						</figure>
						<span class="lqd-fb-icn">
							<i class="lqd-icn-ess icon-ion-ios-arrow-forward"></i>
						</span>
					</div>

					<div class="lqd-fb-content">
						<?php if( !empty( $settings['title'] ) ) { ?>
						<h2 class="my-0"><?php echo $settings['title']; ?></h2>
						<?php } ?>
						
					</div>

					<a href="<?php echo esc_url($settings['img_link']['url']); ?>" class="liquid-overlay-link"><?php echo $settings['title']; ?></a>

				</div>
				<?php
				break;
		}
		?> 
		</div>
		<?php


	}

}
