<?php
namespace LiquidElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Schemes\Color;
use Elementor\Schemes\Typography;
use Elementor\Utils;
use Elementor\Control_Media;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Repeater;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Elementor heading widget.
 *
 * Elementor widget that displays an eye-catching headlines.
 *
 * @since 1.0.0
 */
class LD_Header_Fullproj extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve heading widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'ld_header_fullproj';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve heading widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Liquid Header Fullscreen Project', 'hub-elementor-addons' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve heading widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-site-identity lqd-element';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the heading widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'hub-header' ];
	}

	/**
	 * Get widget keywords.
	 *
	 * Retrieve the list of keywords the widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget keywords.
	 */
	public function get_keywords() {
		return [ 'header', 'screen', 'project' ];
	}

	/**
	 * Retrieve the list of scripts the counter widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'threejs' ];
	}

	/**
	 * Register heading widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

		// General Section
		$this->start_controls_section(
			'general_section',
			array(
				'label' => __( 'General', 'hub-elementor-addons' ),
			)
		);

		$this->add_control(
			'label',
			[
				'label' => __( 'Text', 'hub-elementor-addons' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'All Projects', 'hub-elementor-addons' ),
				'placeholder' => __( 'Add text', 'hub-elementor-addons' ),
			]
		);

		$this->add_control(
			'trigger_txt_position',
			[
				'label' => __( 'Trigger Text Position', 'hub-elementor-addons' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'txt-left' => [
						'title' => __( 'Left', 'hub-elementor-addons' ),
						'icon' => 'fa fa-align-left',
					],
					'txt-right' => [
						'title' => __( 'Right', 'hub-elementor-addons' ),
						'icon' => 'fa fa-align-right',
					],
				],
				'default' => 'txt-right',
				'toggle' => false,
			]
		);

		$this->add_control(
			'trigger_style',
			[
				'label' => __( 'Trigger Style', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'style-3',
				'options' => [
					'style-1' => __( 'Style 1', 'hub-elementor-addons' ),
					'style-2' => __( 'Style 2', 'hub-elementor-addons' ),
					'style-3' => __( 'Style 3', 'hub-elementor-addons' ),
					'style-4' => __( 'Style 4', 'hub-elementor-addons' ),
				],
			]
		);

		$this->add_control(
			'trigger_fill',
			[
				'label' => __( 'Trigger Fill', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'bordered',
				'options' => [
					'fill-none' => __( 'None', 'hub-elementor-addons' ),
					'solid' => __( 'Solid', 'hub-elementor-addons' ),
					'bordered' => __( 'Bordered', 'hub-elementor-addons' ),
				],
			]
		);

		$this->add_control(
			'trigger_shape',
			[
				'label' => __( 'Border Shape', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'circle',
				'options' => [
					'' => __( 'None', 'hub-elementor-addons' ),
					'round' => __( 'Round', 'hub-elementor-addons' ),
					'circle' => __( 'Circle', 'hub-elementor-addons' ),
				],
				'condition' => [
					'trigger_fill!' => [ 'fill-none' ]
				],
			]
		);

		$this->add_control(
			'inactive_items_opacity',
			[
				'label' => __( 'Inactive Items Opacity', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 1,
				],
				'selectors' => [
					'{{WRAPPER}} .lqd-fullproj-menu:hover .lqd-fullproj-title' => 'opacity: {{SIZE}};',
				],
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'media_type',
			[
				'label' => __( 'Media Type', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'image',
				'options' => [
					'image' => __( 'Image', 'hub-elementor-addons' ),
					'local_video' => __( 'Video (Local)', 'hub-elementor-addons' ),
				],
			]
		);

		$repeater->add_control(
			'mp4_local_video',
			[
				'label' => __( 'Local Video (mp4)', 'hub-elementor-addons' ),
				'type' => Controls_Manager::TEXT,
				'condition' => [
					'media_type' => 'local_video'
				],
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'webm_local_video',
			[
				'label' => __( 'Local Video (webm)', 'hub-elementor-addons' ),
				'type' => Controls_Manager::TEXT,
				'condition' => [
					'media_type' => 'local_video'
				],
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'image',
			[
				'label' => __( 'Image', 'hub-elementor-addons' ),
				'type' => Controls_Manager::MEDIA,
				'condition' => [
					'media_type' => 'image'
				]
			]
		);

		$repeater->add_control(
			'text',
			[
				'label' => __( 'Title', 'hub-elementor-addons' ),
				'placeholder' => __( 'Add title', 'hub-elementor-addons' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'subtitle',
			[
				'label' => __( 'Subtitle', 'hub-elementor-addons' ),
				'placeholder' => __( 'Add subtitle', 'hub-elementor-addons' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'url',
			[
				'label' => __( 'URL (Link)', 'hub-elementor-addons' ),
				'placeholder' => __( 'Add link', 'hub-elementor-addons' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
			]
		);


		$this->add_control(
			'identities',
			[
				'label' => __( 'Identities', 'hub-elementor-addons' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ text }}}',
				'label_block' => true,
				'separator' => 'before',
			]
		);
		$this->end_controls_section();


		$this->start_controls_section(
			'style_section',
			[
				'label' => __( 'Style', 'hub-elementor-addons' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'custom_typography',
				'label' => __( 'Typography', 'hub-elementor-addons' ),
				'selector' => '{{WRAPPER}} .lqd-fullproj-menu',
			]
		);

		$this->add_control(
			'color',
			[
				'label' => __( 'Link Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{lqd-fullproj-<?php echo $this->get_id(); ?>}} .lqd-fullproj-menu a' => 'color: {{VALUE}}',
				],
				'separator' => 'before'
			]
		);

		$this->add_control(
			'hover_color',
			[
				'label' => __( 'Link Hover Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-fullproj-menu li.lqd-is-active a' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'trigger_color',
			[
				'label' => __( 'Trigger Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-fullproj-trigger .nav-trigger .bar' => 'background: {{VALUE}}; color: {{VALUE}};',
					'{{WRAPPER}} .lqd-fullproj-trigger .nav-trigger .bar:first-child:before, {{WRAPPER}} .lqd-fullproj-trigger .nav-trigger .bar:nth-child(2):before' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'trigger_color_hover',
			[
				'label' => __( 'Trigger Hover Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-fullproj-trigger .nav-trigger:hover .bar' => 'background: {{VALUE}}; color: {{VALUE}};',
					'{{WRAPPER}} .lqd-fullproj-trigger .nav-trigger:hover .bar:first-child:before, {{WRAPPER}} .lqd-fullproj-trigger .nav-trigger:hover .bar:nth-child(2):before' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'trigger_color_active',
			[
				'label' => __( 'Trigger Active Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-fullproj-trigger .nav-trigger.is-active .bar' => 'background: {{VALUE}}; color: {{VALUE}};',
					'{{WRAPPER}} .lqd-fullproj-trigger .nav-trigger.is-active .bar:first-child:before, {{WRAPPER}} .lqd-fullproj-trigger .nav-trigger.is-active .bar:nth-child(2):before' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'trigger_text_color',
			[
				'label' => __( 'Trigger Text Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-fullproj-trigger .nav-trigger' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'shape_color',
			[
				'label' => __( 'Shape Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-fullproj-trigger .nav-trigger.solid .bars:before' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .lqd-fullproj-trigger .nav-trigger.bordered .bars' => 'border-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'shape_hover_color',
			[
				'label' => __( 'Shape Hover Colorr', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-fullproj-trigger .nav-trigger.solid:hover .bars:before' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .lqd-fullproj-trigger .nav-trigger.bordered:hover .bars' => 'border-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'shape_active_color',
			[
				'label' => __( 'Shape Avtive Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-fullproj-trigger .nav-trigger.solid.is-active .bars:before' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .lqd-fullproj-trigger .nav-trigger.bordered.is-active .bars' => 'border-color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();

		// Sticky Colors
		$this->start_controls_section(
			'sticky_color_section',
			[
				'label' => __( 'Sticky Colors', 'hub-elementor-addons' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'sticky_trigger_color',
			[
				'label' => __( 'Trigger Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'.is-stuck {{WRAPPER}} .lqd-fullproj-trigger .nav-trigger .bar, .is-stuck {{WRAPPER}} .lqd-fullproj-trigger .nav-trigger.style-2 .bar:before, .is-stuck {{WRAPPER}} .lqd-fullproj-trigger .nav-trigger.style-2 .bar:after' => 'background: {{VALUE}}',
					'.is-stuck {{WRAPPER}} .lqd-fullproj-trigger .nav-trigger' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'sticky_trigger_color_hover',
			[
				'label' => __( 'Trigger Hover Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'.is-stuck {{WRAPPER}} .lqd-fullproj-trigger .nav-trigger:hover .bar, .is-stuck {{WRAPPER}} .lqd-fullproj-trigger .nav-trigger.style-2:hover .bar:before, .is-stuck {{WRAPPER}} .lqd-fullproj-trigger .nav-trigger.style-2:hover .bar:after' => 'background: {{VALUE}}',
					'.is-stuck {{WRAPPER}} .lqd-fullproj-trigger .nav-trigger:hover' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'sticky_trigger_color_active',
			[
				'label' => __( 'Trigger Actgive Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'.is-stuck {{WRAPPER}} .lqd-fullproj-trigger .nav-trigger.is-active .bar:before, .is-stuck {{WRAPPER}} .lqd-fullproj-trigger .nav-trigger.is-active .bar:after' => 'background: {{VALUE}}',
					'.is-stuck {{WRAPPER}} .lqd-fullproj-trigger .nav-trigger.is-active' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'sticky_trigger_text_color',
			[
				'label' => __( 'Trigger Text Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'.is-stuck {{WRAPPER}} .lqd-fullproj-trigger .nav-trigger .txt' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'sticky_trigger_text_color_hover',
			[
				'label' => __( 'Trigger Hover Text Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'.is-stuck {{WRAPPER}} .lqd-fullproj-trigger .nav-trigger:hover .txt' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'sticky_trigger_text_color_active',
			[
				'label' => __( 'Trigger Active Text Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'.is-stuck {{WRAPPER}} .lqd-fullproj-trigger .nav-trigger.is-active .txt' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'sticky_shape_color',
			[
				'label' => __( 'Shape Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'.is-stuck {{WRAPPER}} .lqd-fullproj-trigger .nav-trigger.solid .bars:before' => 'background-color: {{VALUE}}',
					'.is-stuck {{WRAPPER}} .lqd-fullproj-trigger .nav-trigger.bordered .bars' => 'border-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'sticky_shape_hover_color',
			[
				'label' => __( 'Shape Hover Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'.is-stuck {{WRAPPER}} .lqd-fullproj-trigger .nav-trigger.solid:hover .bars:before' => 'background-color: {{VALUE}}',
					'.is-stuck {{WRAPPER}} .lqd-fullproj-trigger .nav-trigger.bordered:hover .bars' => 'border-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'sticky_shape_active_color',
			[
				'label' => __( 'Shape Active Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'.is-stuck {{WRAPPER}} .lqd-fullproj-trigger .nav-trigger.solid.is-active .bars:before' => 'background-color: {{VALUE}}',
					'.is-stuck {{WRAPPER}} .lqd-fullproj-trigger .nav-trigger.bordered.is-active .bars' => 'border-color: {{VALUE}}',
				],
			]
		);
		$this->end_controls_section();

		// Colors Over Light Rows
		$this->start_controls_section(
			'sticky_light_section',
			[
				'label' => __( 'Colors Over Light Rows', 'hub-elementor-addons' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'sticky_light_trigger_color',
			[
				'label' => __( 'Trigger Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}.lqd-active-row-light .lqd-fullproj-trigger .nav-trigger .bar' => 'background: {{VALUE}}; color: {{VALUE}};',
					'{{WRAPPER}}.lqd-active-row-light .lqd-fullproj-trigger .nav-trigger.style-2 .bar:before, {{WRAPPER}}.lqd-active-row-light .lqd-fullproj-trigger .nav-trigger.style-2 .bar:after' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'sticky_light_trigger_color_hover',
			[
				'label' => __( 'Trigger Hover Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}.lqd-active-row-light .lqd-fullproj-trigger .nav-trigger:hover .bar' => 'background: {{VALUE}}; color: {{VALUE}};',
					'{{WRAPPER}}.lqd-active-row-light .lqd-fullproj-trigger .nav-trigger.style-2:hover .bar:before, {{WRAPPER}}.lqd-active-row-light .lqd-fullproj-trigger .nav-trigger.style-2:hover .bar:after' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'sticky_light_trigger_color_active',
			[
				'label' => __( 'Trigger Actgive Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}.lqd-active-row-light .lqd-fullproj-trigger .nav-trigger.is-active .bar' => 'background: {{VALUE}}; color: {{VALUE}};',
					'{{WRAPPER}}.lqd-active-row-light .lqd-fullproj-trigger .nav-trigger.style-2.is-active .bar:before, {{WRAPPER}}.lqd-active-row-light .lqd-fullproj-trigger .nav-trigger.style-2.is-active .bar:after' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'sticky_light_trigger_text_color',
			[
				'label' => __( 'Trigger Text Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}.lqd-active-row-light .lqd-fullproj-trigger .nav-trigger > .txt' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'sticky_light_trigger_text_color_hover',
			[
				'label' => __( 'Trigger Hover Text Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}.lqd-active-row-light .lqd-fullproj-trigger .nav-trigger:hover > .txt' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'sticky_light_trigger_text_color_active',
			[
				'label' => __( 'Trigger Active Text Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}.lqd-active-row-light .lqd-fullproj-trigger .nav-trigger.is-active > .txt' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'sticky_light_shape_color',
			[
				'label' => __( 'Shape Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}.lqd-active-row-light .lqd-fullproj-trigger .nav-trigger.solid .bars:before' => 'background-color: {{VALUE}}',
					'{{WRAPPER}}.lqd-active-row-light .lqd-fullproj-trigger .nav-trigger.bordered .bars' => 'border-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'sticky_light_shape_hover_color',
			[
				'label' => __( 'Shape Hover Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}.lqd-active-row-light .lqd-fullproj-trigger .nav-trigger.solid:hover .bars:before' => 'background-color: {{VALUE}}',
					'{{WRAPPER}}.lqd-active-row-light .lqd-fullproj-trigger .nav-trigger.bordered:hover .bars' => 'border-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'sticky_light_shape_active_color',
			[
				'label' => __( 'Shape Active Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}.lqd-active-row-light .lqd-fullproj-trigger .nav-trigger.solid.is-active .bars:before' => 'background-color: {{VALUE}}',
					'{{WRAPPER}}.lqd-active-row-light .lqd-fullproj-trigger .nav-trigger.bordered.is-active .bars' => 'border-color: {{VALUE}}',
				],
			]
		);
		$this->end_controls_section();

		// Colors Over Dark Rows
		$this->start_controls_section(
			'sticky_dark_section',
			[
				'label' => __( 'Colors Over Dark Rows', 'hub-elementor-addons' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'sticky_dark_trigger_color',
			[
				'label' => __( 'Trigger Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}.lqd-active-row-dark .lqd-fullproj-trigger .nav-trigger .bar' => 'background: {{VALUE}}; color: {{VALUE}};',
					'{{WRAPPER}}.lqd-active-row-dark .lqd-fullproj-trigger .nav-trigger.style-2 .bar:before, {{WRAPPER}}.lqd-active-row-dark .lqd-fullproj-trigger .nav-trigger.style-2 .bar:after' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'sticky_dark_trigger_color_hover',
			[
				'label' => __( 'Trigger Hover Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}.lqd-active-row-dark .lqd-fullproj-trigger .nav-trigger:hover .bar' => 'background: {{VALUE}}; color: {{VALUE}};',
					'{{WRAPPER}}.lqd-active-row-dark .lqd-fullproj-trigger .nav-trigger.style-2:hover .bar:before, {{WRAPPER}}.lqd-active-row-dark .lqd-fullproj-trigger .nav-trigger.style-2:hover .bar:after' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'sticky_dark_trigger_color_active',
			[
				'label' => __( 'Trigger Actgive Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}.lqd-active-row-dark .lqd-fullproj-trigger .nav-trigger.is-active .bar' => 'background: {{VALUE}}; color: {{VALUE}};',
					'{{WRAPPER}}.lqd-active-row-dark .lqd-fullproj-trigger .nav-trigger.style-2.is-active .bar:before, {{WRAPPER}}.lqd-active-row-dark .lqd-fullproj-trigger .nav-trigger.style-2.is-active .bar:after' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'sticky_dark_trigger_text_color',
			[
				'label' => __( 'Trigger Text Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}.lqd-active-row-dark .lqd-fullproj-trigger .nav-trigger > .txt' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'sticky_dark_trigger_text_color_hover',
			[
				'label' => __( 'Trigger Hover Text Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}.lqd-active-row-dark .lqd-fullproj-trigger .nav-trigger:hover > .txt' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'sticky_dark_trigger_text_color_active',
			[
				'label' => __( 'Trigger Active Text Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}.lqd-active-row-dark .lqd-fullproj-trigger .nav-trigger.is-active > .txt' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'sticky_dark_shape_color',
			[
				'label' => __( 'Shape Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}.lqd-active-row-dark .lqd-fullproj-trigger .nav-trigger.solid .bars:before' => 'background-color: {{VALUE}}',
					'{{WRAPPER}}.lqd-active-row-dark .lqd-fullproj-trigger .nav-trigger.bordered .bars' => 'border-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'sticky_dark_shape_hover_color',
			[
				'label' => __( 'Shape Hover Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}.lqd-active-row-dark .lqd-fullproj-trigger .nav-trigger.solid:hover .bars:before' => 'background-color: {{VALUE}}',
					'{{WRAPPER}}.lqd-active-row-dark .lqd-fullproj-trigger .nav-trigger.bordered:hover .bars' => 'border-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'sticky_dark_shape_active_color',
			[
				'label' => __( 'Shape Active Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}.lqd-active-row-dark .lqd-fullproj-trigger .nav-trigger.solid.is-active .bars:before' => 'background-color: {{VALUE}}',
					'{{WRAPPER}}.lqd-active-row-dark .lqd-fullproj-trigger .nav-trigger.bordered.is-active .bars' => 'border-color: {{VALUE}}',
				],
			]
		);
		$this->end_controls_section();

	}

	/**
	 * Render heading widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		
		$settings = $this->get_settings_for_display();
		
		$identities = $settings['identities'];

		if( empty( $identities ) )
			return;

		// classes
		$module_classes = array(
			'module-lqd-fullproj-scrn',
			'no-rotate',
		);
		$fullproj_classes = array( 
			'lqd-fullproj-scrn', 
			'pos-rel', 
			'overflow-hidden', 
			'pos-fix', 
			'pos-tl collapse',
		);
		$trigger_wrap_classes = array( 
			'lqd-fullproj-trigger'
		);
		$trigger_classes = array( 
			'nav-trigger',
			'collapsed',
			$settings['trigger_style'],
			$settings['trigger_fill'], 
			$settings['trigger_shape'],
			$settings['trigger_txt_position'],
		);

		$i = 0;

		?>

			<div class="<?php echo ld_helper()->sanitize_html_classes( $module_classes ) ?>">

				<div class="<?php echo ld_helper()->sanitize_html_classes( $trigger_wrap_classes ) ?>">
					<button
					class="<?php echo ld_helper()->sanitize_html_classes( $trigger_classes ) ?>"
					role="button"
					type="button"
					data-ld-toggle="true"
					data-toggle="collapse"
					data-toggle-options='{ "changeClassnames": {"html": "overflow-hidden"}, "cloneTriggerInTarget": true }'
					data-target="<?php echo '#lqd-fullproj-' . $this->get_id(); ?>"
					aria-expanded="false"
					aria-controls="lqd-fullproj-<?php echo $this->get_id() ?>">
						<span class="bars">
							<span class="bars-inner">
								<span class="bar"></span>
								<span class="bar"></span>
								<span class="bar"></span>
								<i class="loading-spinner"></i>
							</span>
						</span>
						<?php if( !empty( $settings['label'] ) ) { ?>
						<span class="txt"><?php esc_html_e( $settings['label'] ); ?></span>
						<?php } ?>
					</button>
				</div>

				<div id="lqd-fullproj-<?php echo $this->get_id(); ?>" class="<?php echo ld_helper()->sanitize_html_classes( $fullproj_classes ); ?>" data-lqd-fullproj="true" aria-expanded="false">
					
					<span class="lqd-fullproj-loader d-inline-flex pos-abs z-index-3">
						<span class="d-inline-flex circle"></span>
					</span>

					<div class="lqd-fullproj-scrn-inner p-3 p-sm-5 p-md-9">
					
						<div class="lqd-fullproj-menu h1 my-0">
							<ul class="reset-ul d-flex flex-wrap align-items-center" data-active-onhover="true" data-active-onhover-options='{ "triggerHandlers": ["mouseenter"] }'>
								
								<?php foreach ( $identities as $item ) { 
									$i++;
									
									$href_atts = '';
									if( 'image' !== $item['media_type'] ) {
										$href_atts = ' data-video-trigger="true"';
									}
								?>

								<li class="d-inline-flex align-items-center justify-content-between <?php if( $i == 1 ) { echo 'lqd-is-active'; }?> elementor-repeater-item-<?php echo $item['_id']; ?>">
									<a class="lqd-fullproj-link <?php if( $i == 1 ) { echo 'active'; } ?>" href="<?php echo $url = ( !empty( $item['url'] ) ? esc_url( $item['url'] ) : '#' ) ?>" <?php echo $href_atts; ?>>
									
									<?php if( !empty( $item['text'] ) ) { ?>
									<span class="lqd-fullproj-title"><?php echo esc_html( $item['text'] )?> <?php if( !empty( $item['subtitle'] ) ) { ?><small><?php echo esc_html( $item['subtitle'] )?></small><?php } ?></span>
									<?php } ?>

									<span class="lqd-fullproj-media lqd-overlay">
									<?php if( 'image' === $item['media_type'] ) { 
										$alt = get_post_meta( $item['image'], '_wp_attachment_image_alt', true );
									?>
										<img src="<?php echo wp_get_attachment_image_url( $item['image']['id'], 'full', false ) ?>" alt="<?php echo esc_attr( $alt ); ?>">
									<?php } else { ?>
										<video>
											<?php if( !empty( $item['mp4_local_video'] ) ) { ?>
												<source src="<?php echo esc_url( $item['mp4_local_video'] ) ?>" type="video/mp4">
											<?php } ?>
											<?php if( !empty( $item['webm_local_video'] ) ) { ?>
												<source src="<?php echo esc_url( $item['webm_local_video'] ) ?>" type="video/webm">
											<?php } ?>
										</video>
									<?php } ?>
									</span>
								</a>
								</li>
								<?php } ?>

							</ul>
						</div>

					</div>

				</div>
			</div>

		<?php

	}

}
