<?php
namespace LiquidElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Schemes\Color;
use Elementor\Schemes\Typography;
use Elementor\Utils;
use Elementor\Control_Media;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Repeater;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Elementor heading widget.
 *
 * Elementor widget that displays an eye-catching headlines.
 *
 * @since 1.0.0
 */
class LD_Pf_Single_Related extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve heading widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'ld_single_portfolio_related';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve heading widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Liquid Portfolio Single Related', 'hub-elementor-addons' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve heading widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-grid lqd-element';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the heading widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'hub-portfolio' ];
	}

	/**
	 * Get widget keywords.
	 *
	 * Retrieve the list of keywords the widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget keywords.
	 */
	public function get_keywords() {
		return [ 'portfolio', 'related', 'post' ];
	}

	/**
	 * Register heading widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
			
	
	}

	/**
	 * Render heading widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		
		//$settings = $this->get_settings_for_display();    

		$related_posts = false;
		if( function_exists( 'liquid_get_post_type_related_posts' ) ) {
			$related_posts = liquid_get_post_type_related_posts( get_the_ID(), 6, 'liquid-portfolio', 'liquid-portfolio-category' );	
		}

		if( !$related_posts ) {
			return;
		}

		?>
			
			<div class="lqd-pf-grid lqd-pf-related-projects">

				<div class="lqd-pf-row carousel-container carousel-nav-floated carousel-nav-center carousel-nav-middle carousel-nav-square carousel-nav-solid carousel-nav-lg carousel-nav-appear-onhover">

					<div class="carousel-items row" data-lqd-flickity='{ "wrapAround": true, "prevNextButtons": true, "navArrow": 6, "navOffsets": {"nav": { "top": "35%" }, "prev": "15px", "next": "15px" } }'>

						<?php while( $related_posts->have_posts() ): $related_posts->the_post(); ?>

						<div class="lqd-pf-column carousel-item col-xs-6 col-sm-4 col-md-3">

							<div class="carousel-item-inner">

								<div class="lqd-pf-item lqd-pf-item-style-2 pos-rel mb-2">
									<div class="lqd-pf-item-inner">
					
										<div class="lqd-pf-img mb-3 pos-rel border-radius-5 overflow-hidden">

											<figure>
												<?php echo liquid_the_post_thumbnail( 'liquid-portfolio-sq', array( 'class' => 'w-100' ), false ); ?>
											</figure>

											<span class="lqd-pf-overlay-bg lqd-overlay align-items-center justify-content-center">
												<i class="lqd-icn-ess icon-md-arrow-forward"></i>
											</span>
										</div>
					
										<div class="lqd-pf-details">
											<?php the_title( sprintf( '<h2 class="mt-0 mb-1 h5"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' ) ?>
											<?php
												$terms = get_the_terms( get_the_ID(), 'liquid-portfolio-category' );
												$term = $terms[0];
												if( isset( $term ) ) {
													echo '<ul class="reset-ul inline-nav lqd-pf-cat pos-rel z-index-2"><li><a href="' . get_term_link( $term->slug, 'liquid-portfolio-category' ) . '">' . esc_html( $term->name ) . '</a></li></ul>';
												}
											?>
										</div>
					
										<a href="<?php the_permalink() ?>" class="lqd-pf-overlay-link lqd-overlay z-index-1"></a>
					
									</div>
								</div>

							</div>
							
						</div>

						<?php endwhile; ?>


					</div>

				</div>
			</div>
		<?php wp_reset_postdata();
		

	}

}
