<?php
namespace LiquidElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Utils;
use Elementor\Control_Media;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Repeater;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Elementor heading widget.
 *
 * Elementor widget that displays an eye-catching headlines.
 *
 * @since 1.0.0
 */
class LD_Testimonial extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve heading widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'ld_testimonial';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve heading widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Liquid Testimonial', 'hub-elementor-addons' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve heading widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-testimonial lqd-element';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the heading widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'hub-core' ];
	}

	/**
	 * Get widget keywords.
	 *
	 * Retrieve the list of keywords the widget belongs to.
	 *
	 * @since 2.1.0
	 * @access public
	 *
	 * @return array Widget keywords.
	 */
	public function get_keywords() {
		return [ 'testimonial', 'comment', ];
	}

	/**
	 * Register heading widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'general_section',
			[
				'label' => __( 'General', 'hub-elementor-addons' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'template',
			[
				'label' => __( 'Style', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'style01',
				'options' => [
					'style01' => __( 'Style 1', 'hub-elementor-addons' ),
					'style02' => __( 'Style 2', 'hub-elementor-addons' ),
					'style03' => __( 'Style 3', 'hub-elementor-addons' ),
					'style04' => __( 'Style 4', 'hub-elementor-addons' ),
					'style05' => __( 'Style 5', 'hub-elementor-addons' ),
					'style06' => __( 'Style 6', 'hub-elementor-addons' ),
					'style07' => __( 'Style 7', 'hub-elementor-addons' ),
					'style08' => __( 'Style 8', 'hub-elementor-addons' ),
					'style09' => __( 'Style 9', 'hub-elementor-addons' ),
					'style10' => __( 'Style 10', 'hub-elementor-addons' ),
					'style11' => __( 'Style 11', 'hub-elementor-addons' ),
					'style12' => __( 'Style 12', 'hub-elementor-addons' ),
					'style13' => __( 'Style 13', 'hub-elementor-addons' ),
					'style14' => __( 'Style 14', 'hub-elementor-addons' ),
					'style15' => __( 'Style 15', 'hub-elementor-addons' ),
					'style16' => __( 'Style 16', 'hub-elementor-addons' ),
					'style17' => __( 'Style 17', 'hub-elementor-addons' ),
					'style18' => __( 'Style 18', 'hub-elementor-addons' ),
					'style19' => __( 'Style 19', 'hub-elementor-addons' ),
				],
			]
		);

		$this->add_control(
			'title',
			[
				'label' => __( 'Name', 'hub-elementor-addons' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'John Doe', 'hub-elementor-addons' ),
				'placeholder' => __( 'Type your name here', 'hub-elementor-addons' ),
			]
		);

		$this->add_control(
			'position',
			[
				'label' => __( 'Position', 'hub-elementor-addons' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Developer', 'hub-elementor-addons' ),
				'placeholder' => __( 'Type your position here', 'hub-elementor-addons' ),
			]
		);

		$this->add_control(
			'avatar',
			[
				'label' => __( 'Avatar', 'hub-elementor-addons' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'template!' => [ 'style19' ],
				],
			]
		);

	
		$this->add_control(
			'content',
			[
				'label' => __( 'Text', 'hub-elementor-addons' ),
				'type' => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Type your text here', 'hub-elementor-addons' ),
				'default' => __( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'hub-elementor-addons' ),
			]
		);

		// Addional Section
		$this->add_control(
			'more_options',
			[
				'label' => __( 'Additional Options', 'hub-elementor-addons' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'template' => [ 'style02', 'style03', 'style04', 'style05', 'style07', 'style08', 'style09', 'style11', 'style16', 'style18', 'style19' ],
				],
			]
		);

		$this->add_control(
			'image',
			[
				'label' => __( 'Client Image', 'hub-elementor-addons' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'template' => [ 'style05', 'style16', 'style18', 'style19' ],
				],
			]
		);

		$this->add_control(
			'rating',
			[
				'label' => __( 'Rating/Stars', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 5,
						'step' => 1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 0,
				],
				'condition' => [
					'template' => [ 'style02', 'style04', 'style05', 'style09', 'style11', 'style18', 'style19' ],
				],
			]
		);

		$this->add_control(
			'date_time',
			[
				'label' => __( 'Data/Time', 'hub-elementor-addons' ),
				'type' => Controls_Manager::TEXT,
				'placeholder' => __( 'Type your Data/Time here', 'hub-elementor-addons' ),
				'condition' => [
					'template' => 'style04',
				],
			]
		);

		$this->add_control(
			'network',
			[
				'label' => __( 'Network', 'hub-elementor-addons' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'fa-amazon',
				'options' => [
					'fa-amazon' => __('Amazon', 'hub-elementor-addons'),
					'fa-behance' => __('Behance', 'hub-elementor-addons'),
					'fa-behance-square' => __('Behance Square', 'hub-elementor-addons'),
					'fa-codepen' => __('Codepen', 'hub-elementor-addons'),
					'fa-deviantart' => __('Deviantart', 'hub-elementor-addons'),
					'fa-digg' => __('Digg', 'hub-elementor-addons'),
					'fa-dribbble' => __('Dribbble', 'hub-elementor-addons'),
					'fa-facebook' => __('Facebook', 'hub-elementor-addons'),
					'fa-facebook-square' => __('Facebook Square', 'hub-elementor-addons'),
					'fa-flickr' => __('Flickr', 'hub-elementor-addons'),
					'fa-github' => __('Github', 'hub-elementor-addons'),
					'fa-google' => __('Google', 'hub-elementor-addons'),
					'fa-google-plus' => __('Google Plus', 'hub-elementor-addons'),
					'fa-instagram' => __('Instagram', 'hub-elementor-addons'),
					'fa-jsfiddle' => __('Jsfiddle', 'hub-elementor-addons'),
					'fa-linkedin' => __('Linkedin', 'hub-elementor-addons'),
					'fa-medium' => __('Medium', 'hub-elementor-addons'),
					'fa-paypal' => __('Paypal', 'hub-elementor-addons'),
					'fa-pinterest' => __('Pinterest', 'hub-elementor-addons'),
					'fa-pinterest-p' => __('Pinterest', 'hub-elementor-addons'),
					'fa-reddit' => __('Reddit', 'hub-elementor-addons'),
					'fa-reddit-square' => __('Reddit Square', 'hub-elementor-addons'),
					'fa-rss' => __('RSS', 'hub-elementor-addons'),
					'fa-rss-square' => __('RSS Square', 'hub-elementor-addons'),
					'fa-skype' => __('Skype', 'hub-elementor-addons'),
					'fa-slack' => __('Slack', 'hub-elementor-addons'),
					'fa-snapchat' => __('Snapchat', 'hub-elementor-addons'),
					'fa-soundcloud' => __('Sound Cloud', 'hub-elementor-addons'),
					'fa-spotify' => __('Spotify', 'hub-elementor-addons'),
					'fa-stack-overflow' => __('Stack Overflow', 'hub-elementor-addons'),
					'fa-telegram' => __('Telegram', 'hub-elementor-addons'),
					'fa-trello' => __('Trello', 'hub-elementor-addons'),
					'fa-tumblr' => __('Tumblr', 'hub-elementor-addons'),
					'fa-twitch' => __('Twitch', 'hub-elementor-addons'),
					'fa-twitter' => __('Twitter', 'hub-elementor-addons'),
					'fa-twitter-square' => __('Twitter Square', 'hub-elementor-addons'),
					'fa-vimeo' => __('Vimeo', 'hub-elementor-addons'),
					'fa-wordpress' => __('Wordpress', 'hub-elementor-addons'),
					'fa-youtube' => __('Youtube', 'hub-elementor-addons'),
					'fa-weixin' => __('Weixin', 'hub-elementor-addons'),
					'fa-weibo' => __('Weibo', 'hub-elementor-addons'),
					'fa-whatsapp' => __('WhatsApp', 'hub-elementor-addons'),
					'fa-yahoo' => __('Yahoo', 'hub-elementor-addons'),
					'fa-tencent-weibo' => __('Tencent-weibo', 'hub-elementor-addons'),
					'fa-renren' => __('Renren', 'hub-elementor-addons'),
					'fa-qq' => __('Qq', 'hub-elementor-addons'),
				],
				'condition' => [
					'template' => [ 'style03', 'style04', 'style08', 'style07' ],
				],
			]
		);
		$this->end_controls_section();

		// Style Tab
		$this->start_controls_section(
			'style_section',
			[
				'label' => __( 'Style', 'hub-elementor-addons' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'testi_content_typography',
				'label' => __( 'Content Typography', 'hub-elementor-addons' ),
				'selector' => '{{WRAPPER}} .lqd-testi-quote blockquote',
			]
		);

		$this->add_control(
			'bg_color',
			[
				'label' => __( 'Background Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-testi' => 'background: {{VALUE}}',
				],
				'condition' => [
					'template!' => [ 'style2', 'style15', 'style17' ],
				],
			]
		);

		$this->add_control(
			'bg_color_style2',
			[
				'label' => __( 'Background Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-testi' => 'background: {{VALUE}}',
					'{{WRAPPER}} .lqd-testi:after' => 'border-top-color: {{VALUE}}',
				],
				'condition' => [
					'template' => [ 'style2' ],
				],
			]
		);

		$this->add_control(
			'bg_color_style15',
			[
				'label' => __( 'Background Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-testi .lqd-testi-inner' => 'background: {{VALUE}}',
					'{{WRAPPER}} .lqd-testi:after' => 'border-left-color: {{VALUE}}',
				],
				'condition' => [
					'template' => [ 'style15' ],
				],
			]
		);

		$this->add_control(
			'bg_color_style17',
			[
				'label' => __( 'Background Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-testi .lqd-testi-quote' => 'background: {{VALUE}}',
					'{{WRAPPER}} .lqd-testi .lqd-testi-quote:after' => 'border-top-color: {{VALUE}}',
				],
				'condition' => [
					'template' => [ 'style17' ],
				],
			]
		);

		$this->add_control(
			'border_color',
			[
				'label' => __( 'Border Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-testi' => 'border-color: {{VALUE}}',
					'{{WRAPPER}} .lqd-testi.lqd-testi-style-2:after' => 'border-top-color: {{VALUE}}',
				],
				'condition' => [
					'template' => [ 'style02', 'style09', 'style15' ],
				],
			]
		);

		$this->add_control(
			'border_color_style18',
			[
				'label' => __( 'Border Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-testi:before' => 'background: {{VALUE}}',
				],
				'condition' => [
					'template' => [ 'style18' ],
				],
			]
		);

		$this->add_control(
			'secondary_color',
			[
				'label' => __( 'Secondary Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-testi-quote-icon path, {{WRAPPER}} .lqd-testi-quote-icon circle' => 'fill: {{VALUE}}',
				],
				'condition' => [
					'template' => [ 'style10', 'style12', 'style16' ],
				],
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => __( 'Title Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-testi h3' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'pos_color',
			[
				'label' => __( 'Position Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-testi h4' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'text_color',
			[
				'label' => __( 'Text Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-testi-quote' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'star_color',
			[
				'label' => __( 'Star/Rating Color', 'hub-elementor-addons' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lqd-testi .lqd-star-rating .active' => 'color: {{VALUE}}',
					'{{WRAPPER}} .lqd-testi .lqd-star-rating-fill:before' => 'background: {{VALUE}}',
				],
				'condition' => [
					'template' => [ 'style02', 'style04', 'style05', 'style09', 'style11', 'style18', 'style19' ],
				],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render heading widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		
		$settings = $this->get_settings_for_display();

		$classes = array( 
			'lqd-testi' 
		);

		$template = new \LD_Testimonial_Template_Handler();
		$template->testimonials_template(
			$settings['template'], 
			$settings['content'],
			$settings['avatar'],
			$settings['title'],
			$settings['position'],
			$settings['rating'],
			$settings['network'],
			$settings['date_time'],
			$settings['image']
		);
		
		
	}

	protected function _content_template() {
	?>
		<#

		function ld_testi_get_classes( style ) {

			var hash = [];
			hash['style01'] = 'lqd-testi-style-1 d-flex flex-column-reverse lqd-testi-card lqd-testi-shadow-xs lqd-testi-details-lg lqd-testi-quote-18 lqd-testi-avatar-72';
			hash['style02'] = 'lqd-testi-style-2 d-flex flex-column lqd-testi-card lqd-testi-shadow-none lqd-testi-details-sm lqd-testi-quote-18 lqd-testi-avatar-60 lqd-testi-bubble-all lqd-testi-outline';
			hash['style03'] = 'lqd-testi-style-3 d-flex flex-column lqd-testi-card lqd-testi-shadow-xs lqd-testi-quote-21 lqd-testi-avatar-60';
			hash['style04'] = 'lqd-testi-style-4 d-flex flex-row-reverse lqd-testi-card lqd-testi-shadow-xxl lqd-testi-quote-15 lqd-testi-avatar-65';
			hash['style05'] = 'lqd-testi-style-5 d-flex flex-column lqd-testi-card lqd-testi-details-sm lqd-testi-quote-22 lqd-testi-avatar-48';
			hash['style06'] = 'lqd-testi-style-6 d-flex flex-column lqd-testi-card lqd-testi-details-sm lqd-testi-quote-21 lqd-testi-avatar-48 pt-8 pb-8 text-center';
			hash['style07'] = 'lqd-testi-style-7 d-flex flex-wrap align-items-stretch p-0 lqd-testi-card lqd-testi-shadow-lg lqd-testi-quote-21';
			hash['style08'] = 'lqd-testi-style-8 d-flex flex-column-reverse lqd-testi-card lqd-testi-shadow-none lqd-testi-details-sm lqd-testi-quote-16 lqd-testi-avatar-48';
			hash['style09'] = 'lqd-testi-style-9 d-flex flex-column-reverse lqd-testi-brd round lqd-testi-details-sm lqd-testi-quote-16 lqd-testi-avatar-48';
			hash['style10'] = 'lqd-testi-style-10 d-flex flex-column lqd-testi-card lqd-testi-shadow-none lqd-testi-details-sm lqd-testi-quote-18 lqd-testi-avatar-65 text-center';
			hash['style11'] = 'lqd-testi-style-11 d-flex flex-column lqd-testi-card lqd-testi-shadow-sm lqd-testi-details-sm lqd-testi-quote-18 lqd-testi-avatar-48 text-center';
			hash['style12'] = 'lqd-testi-style-12 lqd-testi-quote-18 lqd-testi-avatar-65';
			hash['style13'] = 'lqd-testi-style-13 d-flex flex-wrap lqd-testi-details-sm lqd-testi-quote-25 lqd-testi-avatar-72';
			hash['style14'] = 'lqd-testi-style-14 d-flex flex-column-reverse lqd-testi-details-xl lqd-testi-quote-22 lqd-testi-avatar-90';
			hash['style15'] = 'lqd-testi-style-15 d-flex flex-wrap lqd-testi-bubble round lqd-testi-details-lg lqd-testi-quote-25';
			hash['style16'] = 'lqd-testi-style-16 d-flex flex-wrap align-items-stretch p-0 lqd-testi-card lqd-testi-shadow-xl lqd-testi-quote-27';
			hash['style17'] = 'lqd-testi-style-17 lqd-testi-avatar-85 lqd-testi-details-sm lqd-testi-quote-16 text-center lqd-testi-bubble-alt';
			hash['style18'] = 'lqd-testi-style-18 pt-6 pb-4 lqd-testi-shadow-sm2 lqd-testi-details-sm lqd-testi-quote-18 lqd-testi-avatar-68 text-center';
			hash['style19'] = 'lqd-testi-style-19 d-flex flex-column lqd-testi-card lqd-testi-shadow-sm lqd-testi-details-same lqd-testi-details-inline lqd-testi-quote-18 lqd-testi-avatar-60';

			return hash [ style ];
		}

		function ld_testi_get_quote() {
			if( settings.content ) {
				return `<blockquote>${settings.content}</blockquote>`;
			}
		}

		function ld_testi_get_avatar( classnames = null ) {

			if( ! settings.avatar || !settings.avatar.url ) { return ''; }

			var alt = settings.title,
				avatar = '',
				template = settings.template;
			
			if ( 'style07' === template || 'style16' === template ) {
				avatar = `<img class="w-100 h-100 flex-grow objfit-cover objpos-center" src="${avatar}" alt="${alt}" />`;
			} else {
				// Default
				avatar = `<img class="circle" src="${avatar}" alt="${alt}" />`;
			}
			

			if ( 'style07' === template || 'style16' === template ) {
				avatar = `<figure class="lqd-testi-avatar d-flex w-100 m-0 mx-0">${avatar}</figure>`;
			} else if ( 'style17' === template ) {
				avatar = `<figure class="lqd-testi-avatar circle overflow-hidden mx-0 mb-2">${avatar}</figure>`;
			} else {
				// Default
				avatar =  `<figure class="lqd-testi-avatar ${classnames}">${avatar}</figure>`;
			}

			return avatar;
		}

		function ld_testi_get_name( tag = 'h3', classes = null ) {

			var name = settings.title;
			if( !name ) {
				return '';
			}
			var classnames = '';
			if( classes ) {
				classnames = 'class="' + classes + '"';
			}

			return `<${tag} ${classnames}>${name}</${tag}>`;
		}

		function ld_testi_get_position( tag = 'h4', classes = null ) {

			var style = settings.template,
				position = settings.position,
				classnames = '';

			if( !position  ) { return ''; }

			if( classes ) {
				classes = 'class="' + classes + '"';
			}		

			return `<${tag} ${classes}>${position}</${tag}>`;

		}

		function ld_testi_get_rating( classx = '' ) {
			
			var out = active = '',
			rating = settings.rating.size;
			if( !rating ) { return ''; }

			out += '<ul class="lqd-star-rating ' + classx + '">';
			for( let i = 1; i <= 5; i++ ) {
				if( i <= rating ) {
					active = ' active';
				} else {
					active = '';
				}
				out += '<li><i class="fa fa-star' + active + '"></i></li> ';
			}
			out += '</ul>';

			return out;

		}

		function ld_testi_get_social_icon() {
			if( settings.network ) {
				return `<div class="lqd-testi-social-icon branded-text"><i class="fa ${settings.network}"></i></div>`;
			}		
		}

		function ld_testi_get_time( class_t = null ) {

			var time = settings.date_time,
				style = settings.template;

			if( !time ) { return ''; }

			if ( class_t ) {
				class_t = 'class="lqd-testi-time ' + class_t + '"';
			} else {
				class_t = 'class="lqd-testi-time"';
			}

			return `<span ${class_t}>${time}</span>`;

		}

		function ld_testi_get_image() {
			if( settings.image.url ) { 
				return `<figure><img src="${settings.image.url}" alt="${settings.title}" /></figure>`;
			}
		}
		
		function ld_get_testi_content( style ){

			switch( style ){
				case 'style01':
				return `
					<div class="lqd-testi-quote mb-1">
						${ld_testi_get_quote()}
					</div>
					<div class="lqd-testi-info d-flex flex-wrap justify-content-between mb-3">
						<div class="lqd-testi-details">
							${ld_testi_get_avatar()}
							<div class="lqd-testi-np">
							${ld_testi_get_name('h3')}
							${ld_testi_get_position( 'h4', 'font-weight-light' )}
							</div>
						</div>
					</div>`
				break;
				case 'style02':
					return `
					<div class="lqd-testi-quote mb-4">
						${ld_testi_get_quote()}
					</div>
					<div class="lqd-testi-info d-flex flex-column flex-wrap justify-content-between">
						${ld_testi_get_rating('mb-5')}

						<div class="lqd-testi-details">
							${ld_testi_get_avatar()}
							<div class="lqd-testi-np">
								${ld_testi_get_name('h3')}
								${ld_testi_get_position( 'h4' )}
							</div>
						</div>
					</div>`;
				break;
				case 'style03':
					return `
					<div class="lqd-testi-quote mb-md-9">
						${ld_testi_get_quote()}
					</div>
					<div class="lqd-testi-info d-flex flex-wrap justify-content-between mt-md-6">

						<div class="lqd-testi-details">
							${ld_testi_get_avatar()}
							<div class="lqd-testi-np">
								${ld_testi_get_name()}
								${ld_testi_get_position()}
							</div>
						</div>
						${ld_testi_get_social_icon()}
					</div>
					`;
				break;
				case 'style04':
					return `
					<div class="d-flex flex-column flex-grow">

						<div class="lqd-testi-info d-flex flex-wrap align-items-center justify-content-between mb-2">
							<div class="lqd-testi-np">
								${ld_testi_get_name('h3', 'font-weight-medium')}
								${ld_testi_get_position( 'h4', 'font-weight-light' )}
							</div>
							${ld_testi_get_social_icon()}	
						</div>
						<div class="lqd-testi-quote mb-1">
							${ld_testi_get_quote()}
						</div>
						<div class="lqd-testi-details">
							${ld_testi_get_time('font-weight-medium')}
							${ld_testi_get_rating('mt-2')}
						</div>
					</div>
					<div class="lqd-testi-details">
						${ld_testi_get_avatar()}
					</div>
					`;
				break;
				case 'style05':
					return `
					<div class="lqd-testi-extra mb-3">
						${ld_testi_get_image()}
					</div>
					<div class="lqd-testi-quote mb-4">
						${ld_testi_get_quote()}
					</div>
					<div class="lqd-testi-info d-flex flex-column flex-wrap justify-content-between">
						${ld_testi_get_rating('mb-6')}
						<div class="lqd-testi-details">
							${ld_testi_get_avatar()}
							<div class="lqd-testi-np">
								${ld_testi_get_name()}
								${ld_testi_get_position()}
							</div>
						</div>
					</div>
					`;
				break;
				case 'style06':
					return `
					<div class="lqd-testi-quote w-75 mx-auto mb-7">
						${ld_testi_get_quote()}
					</div>
					<div class="lqd-testi-info d-flex flex-column flex-wrap justify-content-between">
						<div class="lqd-testi-details">
							${ld_testi_get_avatar()}
							<div class="lqd-testi-np">
								${ld_testi_get_name()}
								${ld_testi_get_position()}
							</div>
						</div>
					</div>
					`;
				break;
				case 'style07':
					return `
					<div class="lqd-testi-details d-flex align-items-stretch w-40">
						${ld_testi_get_avatar()}
					</div>
					<div class="d-flex flex-column justify-content-center w-60 py-5 px-6">
						<div class="lqd-testi-quote mb-5">
							${ld_testi_get_quote()}
						</div>
						<div class="lqd-testi-info d-flex flex-wrap justify-content-between">
							<div class="lqd-testi-details">
								<div class="lqd-testi-np">
									${ld_testi_get_name()}
									${ld_testi_get_position()}
								</div>
							</div>
							${ld_testi_get_social_icon()}
						</div>
					</div>
					`;
				break;
				case 'style08':
					return `
					<div class="lqd-testi-quote mb-1">
						${ld_testi_get_quote()}
					</div>
					<div class="lqd-testi-info d-flex flex-wrap justify-content-between mb-4">
						<div class="lqd-testi-details">
							${ld_testi_get_avatar()}
							<div class="lqd-testi-np">
								${ld_testi_get_name('h3', 'font-weight-medium')}
								${ld_testi_get_position()}
							</div>
						</div>
						${ld_testi_get_social_icon()}
					</div>
					`;
				break;
				case 'style09':
					return `
					<div class="lqd-testi-quote mb-1 px-4 py-4">
						${ld_testi_get_quote()}
						${ld_testi_get_rating('mt-4')}
					</div>
					<div class="lqd-testi-info d-flex flex-wrap px-4 py-3">
						<div class="lqd-testi-details d-flex flex-wrap flex-row-reverse justify-content-between w-100">
							${ld_testi_get_avatar('mx-0')}
							<div class="lqd-testi-np">
								${ld_testi_get_name('h3', 'font-weight-medium')}
								${ld_testi_get_position()}
							</div>
						</div>
					</div>
					`;
				break;
				case 'style10':
					return `
					<div class="lqd-testi-extra mt-2 mb-4">
						<svg class="lqd-testi-quote-icon lqd-testi-quote-icon-flip" xmlns="http://www.w3.org/2000/svg" width="48" height="48" viewBox="0 0 48 48">
							<circle cx="24" cy="24" r="24"/>
							<path d="M33.6506355,22.4458786 C34.1870129,24.3649793 34.1999448,26.4569702 33.6852534,28.1856729 C33.115054,30.1017893 31.9414302,31.3977692 30.3804449,31.8340732 C29.9875127,31.9440942 29.5828423,32 29.177575,32 C27.1880449,32 25.4239286,30.6602504 24.8875513,28.7425424 C24.2258336,26.3757974 25.612536,23.9115654 27.9796789,23.2492508 C29.0289571,22.9569888 30.1876594,23.0682036 31.158948,23.5488741 C31.1277124,23.417963 31.0952831,23.2924236 31.0610632,23.1696696 C30.1958165,20.0761493 28.4985484,18.684274 27.5698357,18.684274 L27.5288514,18.6850698 C27.3503906,18.6932269 27.1786941,18.5728603 27.1289559,18.3947974 L26.6134686,16.5509009 C26.5830288,16.4426704 26.5999398,16.3268798 26.6598247,16.2315813 C26.7199085,16.1368797 26.8169976,16.0716231 26.9280133,16.0521257 C27.1237831,16.0175079 27.3247256,16 27.5258671,16 C30.0300887,16 32.6063312,18.7111327 33.6506355,22.4458786 Z M17.2027923,16.0003979 C19.7076107,16.0003979 22.2834553,18.7111327 23.3283565,22.4454807 C23.8649328,24.3647803 23.8776658,26.4569702 23.3631733,28.1856729 C22.792775,30.1017893 21.6191512,31.3977692 20.0583649,31.8340732 C19.6652337,31.9440942 19.2605633,32 18.855296,32 C16.8657659,32 15.1016496,30.6602504 14.5652723,28.7425424 C13.9031566,26.3757974 15.290257,23.9115654 17.657002,23.2492508 C18.7062802,22.9569888 19.8645846,23.0682036 20.8362711,23.5488741 C20.8052345,23.4187588 20.7728051,23.2932194 20.7383862,23.1696696 C19.8731396,20.0761493 18.1756725,18.684274 17.2469599,18.684274 L17.2063735,18.6850698 C17.0247294,18.6932269 16.8562162,18.5728603 16.8064779,18.3947974 L16.2907917,16.5509009 C16.2605509,16.4426704 16.2774619,16.3268798 16.3373467,16.2315813 C16.3972316,16.1368797 16.4945196,16.0712252 16.6053364,16.0521257 C16.8009072,16.0175079 17.0020487,16.0003979 17.2027923,16.0003979 Z"/>
						</svg>
					</div>
					<div class="lqd-testi-quote mb-6">
						${ld_testi_get_quote()}
					</div>
					<div class="lqd-testi-info mb-1">
						<div class="lqd-testi-details d-flex flex-column">
							${ld_testi_get_avatar('mx-0 mb-2')}
							<div class="lqd-testi-np">
								${ld_testi_get_name('h3', 'font-weight-medium')}
								${ld_testi_get_position()}
							</div>
						</div>
					</div>
					`;
				break;
				case 'style11':
					return `
					<div class="lqd-testi-extra mt-3 mb-5">
						${ld_testi_get_rating()}
					</div>
					<div class="lqd-testi-quote mb-7">
						${ld_testi_get_quote()}
					</div>
					<div class="lqd-testi-info mb-1">
						<div class="lqd-testi-details d-flex flex-column">
							${ld_testi_get_avatar('mx-0 mb-2')}
							<div class="lqd-testi-np">
								${ld_testi_get_name('h3', 'font-weight-medium')}
								${ld_testi_get_position()}
							</div>
						</div>
					</div>
					`;
				break;
				case 'style12':
					return `
					<div class="d-flex flex-wrap">
						<div class="lqd-testi-left-sec w-10">
							<div class="lqd-testi-extra mt-2">
								<svg class="lqd-testi-quote-icon" xmlns="http://www.w3.org/2000/svg" width="38" height="29" viewBox="0 0 38 29">
									<path fill="#348EF5" d="M54.5068359,11.9578125 C49.6617596,14.3406369 47.2392578,17.1404136 47.2392578,20.3572266 C49.3043723,20.595509 51.0120375,21.4394133 52.3623047,22.8889648 C53.7125719,24.3385164 54.3876953,26.0163967 54.3876953,27.9226563 C54.3876953,29.948057 53.7324284,31.6557222 52.421875,33.0457031 C51.1113216,34.435684 49.4632261,35.1306641 47.4775391,35.1306641 C45.2535696,35.1306641 43.3274821,34.22719 41.6992188,32.4202148 C40.0709554,30.6132397 39.2568359,28.4190884 39.2568359,25.8376953 C39.2568359,18.093516 43.5855687,12.0372614 52.2431641,7.66875 L54.5068359,11.9578125 Z M32.7041016,11.9578125 C27.8193115,14.3406369 25.3769531,17.1404136 25.3769531,20.3572266 C27.4817814,20.595509 29.2093031,21.4394133 30.5595703,22.8889648 C31.9098375,24.3385164 32.5849609,26.0163967 32.5849609,27.9226563 C32.5849609,29.948057 31.9197658,31.6557222 30.5893555,33.0457031 C29.2589452,34.435684 27.6009214,35.1306641 25.6152344,35.1306641 C23.3912649,35.1306641 21.4751057,34.22719 19.8666992,32.4202148 C18.2582927,30.6132397 17.4541016,28.4190884 17.4541016,25.8376953 C17.4541016,18.093516 21.7629777,12.0372614 30.3808594,7.66875 L32.7041016,11.9578125 Z" transform="translate(-17 -7)"/>
								</svg>
							</div>
						</div>
						<div class="lqd-testi-right-sec w-90 px-5">
							<div class="d-flex flex-column flex-grow">
								<div class="lqd-testi-quote mb-5">
									${ld_testi_get_quote()}
								</div>
							</div>
							<div class="lqd-testi-details">
								${ld_testi_get_avatar()}
								<div class="lqd-testi-np">
									${ld_testi_get_name()}
									${ld_testi_get_position()}
								</div>
							</div>
						</div>
					</div>
					`;
				break;
				case 'style13':
					return `
					<div class="lqd-testi-quote mb-4">
						${ld_testi_get_quote()}
					</div>
					<div class="lqd-testi-info w-100">
						<div class="lqd-testi-details">
							${ld_testi_get_avatar()}
							<div class="lqd-testi-np">
								${ld_testi_get_name('h3','font-weight-medium')}
								${ld_testi_get_position('h4','font-weight-light')}
							</div>
						</div>
					</div>
					`;
				break;
				case 'style14':
					return `
					<div class="lqd-testi-quote mb-0">
						${ld_testi_get_quote()}
					</div>
					<div class="lqd-testi-info mb-5">
						<div class="lqd-testi-details">
							${ld_testi_get_avatar()}
							<div class="lqd-testi-np">
								${ld_testi_get_name('h3','font-weight-medium')}
								${ld_testi_get_position('h4','font-weight-light')}
							</div>
						</div>
					</div>
					`;
				break;
				case 'style15':
					return `
					<div class="lqd-testi-inner p-6">
						<div class="lqd-testi-quote mb-4">
							${ld_testi_get_quote()}
						</div>
						<div class="lqd-testi-info">
							<div class="lqd-testi-details">
								<div class="lqd-testi-np">
									${ld_testi_get_name('h3','font-weight-medium')}
									${ld_testi_get_position('h4','font-weight-light')}
								</div>
							</div>
						</div>
					</div>
					`;
				break;
				case 'style16':
					return `
					<div class="lqd-testi-details d-flex align-items-stretch w-100 w-sm-50">
						${ld_testi_get_avatar()}
					</div>
					<div class="d-flex flex-column justify-content-center w-100 w-sm-50 p-md-9 p-5">
						<div class="lqd-testi-extra mb-2">
							<svg class="lqd-testi-quote-icon-gradient" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="150" height="131" viewBox="0 0 281.155 245.956">
								<defs>
									<linearGradient id="testi-icon-gradient" x1="0.5" x2="0.5" y2="1" gradientUnits="objectBoundingBox">
										<stop offset="0" stop-color="#e5e9f2" stop-opacity="0.243" />
										<stop offset="1" stop-color="#737579" stop-opacity="0" />
									</linearGradient>
								</defs>
								<path d="M0-37.9v-70.289q0-57.659,26.358-95.549,27.457-38.988,80.173-53.266a12.548,12.548,0,0,1,11.257,2.2,12.28,12.28,0,0,1,5.217,10.433v18.67a12.849,12.849,0,0,1-2.471,7.413,11.344,11.344,0,0,1-6.315,4.668Q57.11-192.758,57.11-134.55H96.647a25.419,25.419,0,0,1,18.67,7.688,25.419,25.419,0,0,1,7.688,18.67V-37.9a25.419,25.419,0,0,1-7.688,18.67,25.419,25.419,0,0,1-18.67,7.688H26.358a25.419,25.419,0,0,1-18.67-7.688A25.419,25.419,0,0,1,0-37.9ZM184.508-11.545H254.8a25.419,25.419,0,0,0,18.67-7.688,25.419,25.419,0,0,0,7.688-18.67v-70.289a25.419,25.419,0,0,0-7.688-18.67,25.419,25.419,0,0,0-18.67-7.688H215.259q0-58.208,57.11-79.075a11.344,11.344,0,0,0,6.315-4.668,12.849,12.849,0,0,0,2.471-7.413v-18.67a12.28,12.28,0,0,0-5.217-10.433,12.548,12.548,0,0,0-11.257-2.2q-52.717,14.277-80.173,53.266-26.358,37.89-26.358,95.549V-37.9a25.419,25.419,0,0,0,7.688,18.67A25.419,25.419,0,0,0,184.508-11.545Z" transform="translate(0 257.5)" fill="url(#testi-icon-gradient)" />
							</svg>
						</div>
						<div class="lqd-testi-quote mb-3">
							${ld_testi_get_quote()}
						</div>
						<div class="lqd-testi-info mb-5">
							<div class="lqd-testi-details">
								<div class="lqd-testi-np">
									${ld_testi_get_name('h3','font-weight-medium')}
									${ld_testi_get_position('h4','font-weight-regular')}
								</div>
							</div>
						</div>
						<div class="lqd-testi-extra">
							${ld_testi_get_image()}
						</div>
					</div>
					`;
				break;
				case 'style17':
					return `
					<div class="lqd-testi-quote pos-rel p-6 mb-6">
						${ld_testi_get_quote()}
					</div>
					<div class="lqd-testi-details d-flex flex-column">
						${ld_testi_get_avatar()}
						<div class="lqd-testi-np">
							${ld_testi_get_name('h3','font-weight-bold')}
							${ld_testi_get_position('h4','font-weight-bold text-uppercase ltr-sp-1')}
						</div>
					</div>
					`;
				break;
				case 'style18':
					return `
					<div class="d-flex justify-content-center mb-4">
						${ld_testi_get_rating( 'lqd-star-rating-outline' )}
					</div>
					<div class="lqd-testi-quote mb-4 px-3 px-md-5">
						${ld_testi_get_quote()}
					</div>
					<div class="lqd-testi-info d-flex flex-column flex-wrap justify-content-between">
						<div class="lqd-testi-details">
							${ld_testi_get_avatar()}
							<div class="lqd-testi-np">
								${ld_testi_get_name( 'h3', 'text-uppercase ltr-sp-1 font-weight-bold' )}
								${ld_testi_get_position()}
							</div>
						</div>
					</div>
					<div class="lqd-testi-extra pt-4 mt-4">
						${ld_testi_get_image()}
					</div>
					`;
				break;
				case 'style19':
					return `
					<div class="lqd-testi-extra mb-4">
						${ld_testi_get_image()}
					</div>
					<div class="lqd-testi-quote mb-4">
						${ld_testi_get_quote()}
					</div>
					<div class="d-flex mb-2">
						${ld_testi_get_rating( 'lqd-star-rating-fill' )}
					</div>
					<div class="lqd-testi-info d-flex flex-column flex-wrap justify-content-between">
						<div class="lqd-testi-details">
							<div class="lqd-testi-np d-flex align-items-center">
								${ld_testi_get_name()}
								${ld_testi_get_position()}
							</div>
						</div>
					</div>
					`;
				break;
			}

		}

		view.addRenderAttribute(
			'wrapper',
			{
				'class': [ 'lqd-testi', ld_testi_get_classes( settings.template ) ],
			}
		);
		#>
		<div {{{ view.getRenderAttributeString( 'wrapper' )}}}>
			{{{ ld_get_testi_content( settings.template ) }}}
		</div>
	<?php
	}

}
